@@ -3,7 +3,7 @@
  *  $Id: ianotador.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -13,6 +13,7 @@
 #pragma once
 
 #include <api/math/geometry.h>
+#include <api/math/geometry3d.h>
 
 namespace GNC {
 	namespace GCS {
@@ -37,7 +38,7 @@ namespace GNC {
 
 			//el comportamiento por defecto de las anotaciones con posicion es el mismo que las de sin posicion
 			//si se desean pueden sobreescribirse
-			virtual std::string GetAnotacionPosicion(GNC::GCS::Vector* pPosicionRaton) = 0;
+			virtual std::string GetAnotacionPosicion(const GNC::GCS::Vector3D& wP, GNC::GCS::Contexto3D* c) = 0;
 		};
 	}
 }
