@@ -3,7 +3,7 @@
  *  $Id: initwx.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -64,6 +64,8 @@
 #include <vtkPolyDataMapper.h>
 
 #include <itkObject.h>
+#include <vtkThreadedStreamingPipeline.h>
+#include <itkMultiThreader.h>
 #if defined(_GINKGO_DEBUG) && !defined(OMITIR_VENTANA_ERRORES_VTK)
 #include <vtkObject.h>
 #endif
@@ -112,6 +114,7 @@
 #include <main/controllers/thumbnailcontroller.h>
 #include <main/controllers/historytoolscontroller.h>
 #include <main/controllers/hangingprotocolcontroller.h>
+#include <main/controllers/autocleaningcontroller.h>
 
 #include <main/gui/mainwindow/ventanaprincipal.h>
 
@@ -274,7 +277,9 @@ bool Ginkgo::OnInit()
 	curl_global_init(CURL_GLOBAL_ALL);
 
 	WriteHeaderLog();
-
+	
+	//esto es para que no casque
+	m_pServer = NULL;
 	#if defined(SINGLE_INSTANCE)
 
 	//check numero de instancias del programa
@@ -285,8 +290,6 @@ bool Ginkgo::OnInit()
 	#else
 	const wxString name(wxT("40000"));
 	#endif
-	//esto es para que no casque
-	m_pServer = NULL;
 	//comprobación una instancia
 	//If using a single instance, use IPC to
 	// communicate with the other instance
@@ -394,7 +397,7 @@ bool Ginkgo::OnInit()
 	#else
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Online manual"), "url_manual", _Std("URL of manual"), true, "http://doc.ginkgo-cadx.com/", true);
 	#endif
-	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Online support"), "url_support", _Std("URL of online support"), true, _Std("http://ginkgo-cadx.com/en/services/"), true);
+	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.help", _Std("Online support"), "url_support", _Std("URL of online support"), true, _Std("http://ginkgo-cadx.com/"), true);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.update", _Std("Program Updates"), "check_updates", _Std("Warn about newest Ginkgo CADx updates"), false, "http://updates.ginkgo-cadx.com/version3.xml", true);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.update", _Std("Program Updates"), "update_period", _Std("Update period (days)"), false, "2", true);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.seguridad",_Std("Security"), "setup_security", _Std("Setup Security"), false, "", false);
@@ -413,6 +416,7 @@ bool Ginkgo::OnInit()
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "quality", _Std("Set compression, 0 implies no compression (0..14)"), false, "1", true);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "codec", _Std("Recompression codec (0=JPEG Baseline(default), 1=JPEG Progressive, 2=JPEG Lossless)"), false, "0", true);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "mantener", _Std("Don't change image codec (if possible)"), false, "", true);
+	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "skip_demographic", _Std("Skip demographic step if it's possible"), false, "", false);
 
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.hl7", _Std("HL7 Service"), "autostart", _Std("Automatically start HL7 Sender service"), false, "", true);
 	GNC::GCS::IControladorPermisos::Instance()->AddDefinicionPermiso("core.integracion", _Std("XML dicomization"), "send_message", _Std("Send Hl7 message when importing"), false, "", false);
@@ -437,6 +441,11 @@ bool Ginkgo::OnInit()
 
 	//
 
+	itk::MultiThreader::SetGlobalDefaultNumberOfThreads(4);
+	itk::MultiThreader::SetGlobalMaximumNumberOfThreads(4);
+	vtkThreadedStreamingPipeline::SetMultiThreadedEnabled(true);
+	vtkThreadedStreamingPipeline::SetAutoPropagatePush(true);
+
 	/*
 	vtkPolyDataMapper* m = vtkPolyDataMapper::New();
 	m->GlobalImmediateModeRenderingOn();
@@ -455,6 +464,7 @@ bool Ginkgo::OnInit()
 	itk::Object::GlobalWarningDisplayOff();
 #endif
 
+
 	wxThread::SetConcurrency(wxThread::GetCPUCount());
 
 	m_pVentanaLogo = NULL;
@@ -497,7 +507,7 @@ bool Ginkgo::OnInit()
 
 		{
 			wxWindowDisabler dis;
-			m_pVentanaPrincipal = new VentanaPrincipal(wxString::FromUTF8(GNC::Entorno::Instance()->GetApplicationName().c_str()));
+			m_pVentanaPrincipal = new VentanaPrincipal(NULL, wxString::FromUTF8(GNC::Entorno::Instance()->GetApplicationName().c_str()));
 			m_pVentanaPrincipal->Hide();
 			SetTopWindow(m_pVentanaPrincipal);
 		}
@@ -591,6 +601,8 @@ bool Ginkgo::OnInit()
 #if defined(_GINKGO_ENABLE_SPLASH)
 	m_pVentanaLogo = NULL;
 #endif
+	//launch auto cleaning controller...
+	GNC::GCS::AutoCleaningController::Instance();
 
 	return TRUE;
 }
@@ -624,6 +636,7 @@ int Ginkgo::OnExit()
 		LOG_ERROR("Core", _Std("Error unregistering tools: ") << ex.str())
 	}
 
+	GNC::GCS::AutoCleaningController::FreeInstance();
 	GNC::GCS::ThumbnailController::FreeInstance();
 	GNC::GCS::HangingProtocolController::FreeInstance();
 	GNC::GCS::ControladorVistas::FreeInstance();
