@@ -4,7 +4,7 @@
  *  $Id: geometry3d.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -90,14 +90,14 @@ namespace GNC {
 				x = (TComp) valX;
 				y = (TComp) valY;
 				z = (TComp) valZ;
-				t = 1.0;
+				t = (TComp) 1.0;
 			}
 
 			template <class TipoComp> inline Vector3D(const TipoComp* const valor) : x(v[0]), y(v[1]), z(v[2]), t(v[3]) {
 				x = (TComp) valor[0];
 				y = (TComp) valor[1];
 				z = (TComp) valor[2];
-				t = 1.0;
+				t = (TComp) 1.0;
 			}
 
 			~Vector3D() {
@@ -113,7 +113,7 @@ namespace GNC {
 				x = (TComp) valX;
 				y = (TComp) valY;
 				z = (TComp) valZ;
-				t = 1.0;
+				t = (TComp) 1.0;
 				return (*this);
 			}
 
@@ -122,10 +122,40 @@ namespace GNC {
 				x = (TComp) valor;
 				y = (TComp) valor;
 				z = (TComp) valor;
-				t = 1.0;
+				t = (TComp) 1.0;
 				return *this;
 			}
 
+			//----------------------------------------------
+			//-- Load and Store
+			//----------------------------------------------
+
+			/* Load from array (interpret ncomp components) */
+			template <class TipoComp> inline void Load(int ncomp, TipoComp* mem) {
+				for (int i = 0; i < 4; ++i) {
+					if (i < ncomp) {
+						v[i] = (TComp) mem[i];
+					}
+					else {
+						if (v[i] == 3) {
+							v[i] = (TComp)0.0;
+						}
+						else {
+							v[i] = (TComp)1.0;
+						}
+					}
+				}
+			}
+
+			/* Store to array (interpret ncomp components) */
+			template <class TipoComp> inline void Store(int ncomp, TipoComp* mem) const {
+				for (int i = 0; i < 4; ++i) {
+					if (i < ncomp) {
+						mem[i] = (TipoComp) v[i];
+					}
+				}
+			}
+
 			//----------------------------------------------
 			//-- Normas Vectoriales, Distancias y Producto Interior
 			//----------------------------------------------
@@ -191,13 +221,18 @@ namespace GNC {
 				return ((TReal)a.x * (TReal)b.x) + ((TReal)a.y * (TReal)b.y) + ((TReal)a.z * (TReal)b.z);
 			}
 
-			/* Devuelve el producto vectorial */
-			inline Vector3D ProductoVectorial(const Vector3D& b) const {
-				const Vector3D& a = *this;
+			/* Devuelve el producto vectorial
+				w =  u  x v = (u_y v_z - u_z v_y) i + (u_z v_x - u_x v_z) j + (u_x v_y - u_y v_x) k 
+				|  i   j   k  |
+				| u.x u.y u.z | = { (u.y*v.z - u.z*v.y), (u.z*v.x - u.x*v.z), (u.x*v.y - u.y*v.x) }
+				| v.x v.y v.z |
+			*/
+			inline Vector3D ProductoVectorial(const Vector3D& v) const {
+				const Vector3D& u = *this;
 				return Vector3D(
-					((TReal)a.y * (TReal)b.z) - ((TReal)b.y * (TReal)a.z),
-					((TReal)a.x * (TReal)b.z) - ((TReal)b.x * (TReal)a.z),
-					((TReal)a.x * (TReal)b.y) - ((TReal)b.x * (TReal)a.y)
+					((TReal)u.y * (TReal)v.z) - ((TReal)u.z * (TReal)v.y),
+					((TReal)u.z * (TReal)v.x) - ((TReal)u.x * (TReal)v.z),
+					((TReal)u.x * (TReal)v.y) - ((TReal)u.y * (TReal)v.x)
 					);
 			}
 
@@ -316,16 +351,16 @@ namespace GNC {
 			}
 
 			/* Devuelve el punto de la proyeccion ortogonal del punto sobre la recta definida por p0 y p1 */
-			inline Vector3D ProyeccionOrtogonalSobreRecta(const Vector3D& /*p0*/, const Vector3D& /*p1*/) const {
-				//return InterseccionEntreRectas(*this, *this + (p1-p0).VectorOrtogonal(), p0, p1);
-				return Vector3D();
+			inline Vector3D ProyeccionOrtogonalSobreRecta(const Vector3D& p0, const Vector3D& p1) const {
+				 typedef Vector3D V;
+				 V vdir = p1 - p0;
+				 V::TComp proj = ( (*this) - p0).ProductoEscalar(vdir);
+				 return p0 + (vdir * proj);
 			}
 
 			/* Devuelve la distancia del punto a la recta definida por p0 y p1 */
-			inline TReal DistanciaARecta(const Vector3D& /*p0*/, const Vector3D& /*p1*/) const {
-				//return (ProyeccionOrtogonalSobreRecta(p0, p1) - (*this)).Norma2();
-				//
-				return 0.0;
+			inline TReal DistanciaARecta(const Vector3D& p0, const Vector3D& p1) const {
+				return (ProyeccionOrtogonalSobreRecta(p0, p1) - (*this)).Norma2();
 			}
 
 			/* Devuelve el cuadrado de la distancia del punto a la recta definida por p0 y p1 */
@@ -401,6 +436,7 @@ namespace GNC {
 				x = std::max(x, val);
 				y = std::max(y, val);
 				z = std::max(z, val);
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -409,6 +445,7 @@ namespace GNC {
 				x = std::min(x, val);
 				y = std::min(y, val);
 				z = std::min(z, val);
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -427,6 +464,7 @@ namespace GNC {
 				x = std::max(x, valx);
 				y = std::max(y, valy);
 				z = std::max(z, valz);
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -435,6 +473,7 @@ namespace GNC {
 				x = std::min(x, valx);
 				y = std::min(y, valy);
 				z = std::min(z, valz);
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -463,6 +502,7 @@ namespace GNC {
 				x = std::max(x, o.x);
 				y = std::max(y, o.y);
 				z = std::max(x, o.z);
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -471,6 +511,7 @@ namespace GNC {
 				x = std::min(x, o.x);
 				y = std::min(y, o.y);
 				z = std::min(z, o.z);
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -507,6 +548,7 @@ namespace GNC {
 				x = std::ceil(x);
 				y = std::ceil(y);
 				z = std::ceil(z);
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -518,6 +560,7 @@ namespace GNC {
 				x = std::floor(x);
 				y = std::floor(y);
 				z = std::floor(z);
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -540,6 +583,7 @@ namespace GNC {
 				x = ValorRedondeado(x);
 				y = ValorRedondeado(y);
 				z = ValorRedondeado(z);
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -592,10 +636,11 @@ namespace GNC {
 
 
 			template <class TipoComp> inline Vector3D& operator=(const TipoComp* const vec) {
-				x = (TComp) vec[0];
-				y = (TComp) vec[1];
-				z = (TComp) vec[2];
-				t = (TComp) vec[3];
+				v[0] = (TComp) vec[0];
+				v[1] = (TComp) vec[1];
+				v[2] = (TComp) vec[2];
+				//v[3] = (TComp) vec[3];
+				v[3] = 1.0;
 				return *this;
 			}
 
@@ -615,6 +660,7 @@ namespace GNC {
 				x *= otro.x;
 				y *= otro.y;
 				z *= otro.z;
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -626,6 +672,7 @@ namespace GNC {
 				x *= (TComp) valor;
 				y *= (TComp) valor;
 				z *= (TComp) valor;
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -637,6 +684,7 @@ namespace GNC {
 				x /= v.x;
 				y /= v.y;
 				z /= v.z;
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -648,6 +696,7 @@ namespace GNC {
 				x /= v;
 				y /= v;
 				z /= v;
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -659,6 +708,7 @@ namespace GNC {
 				x -= otro.x;
 				y -= otro.y;
 				z -= otro.z;
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -666,10 +716,16 @@ namespace GNC {
 				return Vector3D(x - valor, y - valor, z - valor);
 			}
 
+			/** Unary minus **/
+			inline Vector3D operator-() const {
+				return Vector3D(-x, -y, -z);
+			}
+
 			inline Vector3D& operator-=(const TComp& valor) {
 				x -= valor;
 				y -= valor;
 				z -= valor;
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -681,6 +737,7 @@ namespace GNC {
 				x += otro.x;
 				y += otro.y;
 				z += otro.z;
+				t = (TComp) 1.0;
 				return *this;
 			}
 
@@ -693,9 +750,141 @@ namespace GNC {
 				x += (TComp) valor;
 				y += (TComp) valor;
 				z += (TComp) valor;
+				t = (TComp) 1.0;
 				return *this;
 			}
 
+			inline operator TComp *() {
+				return v;
+			}
+
+			inline operator const TComp *() const {
+				return v;
+			}
+
+			//----------------------------------------------
+			//-- Utils
+			//----------------------------------------------
+
+			inline bool InsideOpenedBoundingBox(const Vector3D& p0, const Vector3D& p1) const {
+				bool vx = false;
+				bool vy = false;
+				bool vz = false;
+				if (p0.x < p1.x) {
+					vx = (p0.x < x && x < p1.x);
+				}
+				else {
+					vx = (p1.x < x && x < p0.x);
+				}
+
+				if (p0.y < p1.y) {
+					vy = (p0.y < y && y < p1.y);
+				}
+				else {
+					vy = (p1.y < y && y < p0.y);
+				}
+
+				if (p0.z < p1.z) {
+					vz = (p0.z < z && z < p1.z);
+				}
+				else {
+					vz = (p1.z < z && z < p0.z);
+				}
+
+				return vx && vy && vz;
+			}
+
+			inline bool InsideClosedBoundingBox(const Vector3D& p0, const Vector3D& p1) const {
+				bool vx = false;
+				bool vy = false;
+				bool vz = false;
+				if (p0.x < p1.x) {
+					vx = (p0.x <= x && x <= p1.x);
+				}
+				else {
+					vx = (p1.x <= x && x <= p0.x);
+				}
+
+				if (p0.y < p1.y) {
+					vy = (p0.y <= y && y <= p1.y);
+				}
+				else {
+					vy = (p1.y <= y && y <= p0.y);
+				}
+
+				if (p0.z < p1.z) {
+					vz = (p0.z <= z && z <= p1.z);
+				}
+				else {
+					vz = (p1.z <= z && z <= p0.z);
+				}
+
+				return vx && vy && vz;
+			}
+
+			inline void InitBoundingBox(Vector3D& p0, Vector3D& p1) const {
+				p0 = p1 = *this;
+			}
+
+			inline void InitBoundingBox(Vector3D bBox[2]) const {
+				InitBoundingBox(bBox[0], bBox[1]);
+			}
+
+			inline void ExtendBoundingBox(Vector3D& p0, Vector3D& p1) const {
+				if (p0.x <= p1.x) {
+					if (x < p0.x) {
+						p0.x = x;
+					}
+					else if (x > p1.x) {
+						p1.x = x;
+					}
+				}
+				else {
+					if (x < p1.x) {
+						p1.x = x;
+					}
+					else if (x > p0.x) {
+						p0.x = x;
+					}
+				}
+				if (p0.y <= p1.y) {
+					if (y < p0.y) {
+						p0.y = y;
+					}
+					else if (y > p1.y) {
+						p1.y = y;
+					}
+				}
+				else {
+					if (y < p1.y) {
+						p1.y = y;
+					}
+					else if (y > p0.y) {
+						p0.y = y;
+					}
+				}
+				if (p0.z <= p1.z) {
+					if (z < p0.z) {
+						p0.z = z;
+					}
+					else if (z > p1.z) {
+						p1.z = z;
+					}
+				}
+				else {
+					if (z < p1.z) {
+						p1.z = z;
+					}
+					else if (z > p0.z) {
+						p0.z = z;
+					}
+				}
+			}
+
+			inline void ExtendBoundingBox(Vector3D bBox[2]) const {
+				ExtendBoundingBox(bBox[0], bBox[1]);
+			}
+
 			//----------------------------------------------
 			//-- Accesores
 			//----------------------------------------------
@@ -720,6 +909,22 @@ namespace GNC {
 			}
 		};
 
+		template <class TipoComp> inline Vector3D operator+(const TipoComp val, const Vector3D& o) {
+			return Vector3D( (Vector3D::TComp)val + o.x, (Vector3D::TComp)val + o.y, (Vector3D::TComp)val + o.z );
+		}
+
+		template <class TipoComp> inline Vector3D operator-(const TipoComp val, const Vector3D& o) {
+			return Vector3D( (Vector3D::TComp)val - o.x, (Vector3D::TComp)val - o.y, (Vector3D::TComp)val - o.z );
+		}
+
+		template <class TipoComp> inline Vector3D operator*(const TipoComp val, const Vector3D& o) {
+			return Vector3D( (Vector3D::TComp)val * o.x, (Vector3D::TComp)val * o.y, (Vector3D::TComp)val * o.z );
+		}
+
+		template <class TipoComp> inline Vector3D operator/(const TipoComp val, const Vector3D& o) {
+			return Vector3D( (Vector3D::TComp)val / o.x, (Vector3D::TComp)val / o.y, (Vector3D::TComp)val / o.z );
+		}
+
 		class  Matriz3x3 {
 
 		public:
