@@ -3,7 +3,7 @@
  *  $Id: historycontroller.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -225,6 +225,16 @@ std::string GNC::GCS::History::StudyPatientFilter::GetSQLFilter()
 }
 
 
+std::string GNC::GCS::History::StudyLocationFilter::GetSQLFilter()
+{
+	wxSQLite3StatementBuffer bufSQL;
+	std::ostringstream ostr;
+	ostr << bufSQL.Format("Study.location = '%c'", GNC::GCS::HistoryController::LocationToChar(Location));
+	return ostr.str();
+}
+
+
+
 //region "Patron singleton"
 GNC::GCS::HistoryController* GNC::GCS::HistoryController::m_pInstance = 0;
 
@@ -724,13 +734,18 @@ void GNC::GCS::HistoryController::FindOrInsertStudy(DICOMFileModel& model)
 {
 	std::ostringstream ostrSelect;
 	wxSQLite3StatementBuffer bufSQL;
-	ostrSelect << bufSQL.Format("Select pk from Study where pat_id='%q'",model.study.pat_id.c_str());
+	ostrSelect << bufSQL.Format("SELECT pk from Study where pat_id='%q'",model.study.pat_id.c_str());
 	ostrSelect <<  bufSQL.Format(" AND pat_id_issuer='%q'",model.study.pat_id_issuer.c_str());
 	ostrSelect <<  bufSQL.Format(" AND pat_name='%q'",model.study.pat_name.c_str());
 	ostrSelect <<  bufSQL.Format(" AND study_iuid='%q'",model.study.study_iuid.c_str());
 	ostrSelect <<  bufSQL.Format(" AND study_id='%q'",model.study.study_id.c_str());
 	ostrSelect <<  bufSQL.Format(" AND accession_no='%q'",model.study.study_acc_no.c_str());
-	ostrSelect << "AND pat_sex='" << model.study.pat_sex << "'";
+	if (model.study.pat_sex == '?') {
+		ostrSelect << bufSQL.Format(" AND ( pat_sex = '?' OR pat_sex IS NULL )", model.study.pat_sex);
+	}
+	else {
+		ostrSelect << bufSQL.Format(" AND pat_sex = '%c'", model.study.pat_sex);
+	}
 	if (model.study.pat_bithdate.empty()) {
 		ostrSelect << " AND pat_birthdate IS NULL";
 	} else {
@@ -2034,8 +2049,10 @@ bool GNC::GCS::HistoryController::ReadFile(DICOMFileModel& modeloDCM, const std:
 			modeloDCM.study.pat_sex ='M';
 		}else if(tag.compare("F")==0){
 			modeloDCM.study.pat_sex ='F';
-		}else{
+		}else if (!tag.empty()){
 			modeloDCM.study.pat_sex='O';
+		} else {
+			modeloDCM.study.pat_sex = '?';
 		}
 	}
 
