@@ -3,7 +3,7 @@
  *  $Id: historycontroller.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -131,6 +131,21 @@ namespace GNC {
 			protected:
 				std::string pat_id;
 			};
+
+			class EXTAPI StudyLocationFilter: public IHistoryFilter
+			{
+			public:
+				StudyLocationFilter(GNC::GCS::IHistoryController::TLocation location): Location(location) {}
+
+				StudyLocationFilter() {
+					;
+				}
+
+				virtual std::string GetSQLFilter();
+			protected:
+				GNC::GCS::IHistoryController::TLocation Location;
+			};
+
 		}
 		class EXTAPI HistoryController: public IHistoryController{
 		public:
