@@ -3,7 +3,7 @@
  *  $Id: dialogoconfiguracion.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -33,6 +33,7 @@
 #include "panelconfiguraciongeneral.h"
 #include "panelconfigurationanonymization.h"
 #include "hangingprotocolconfigurationpanel.h"
+#include "localdatabaseconfigurationpanel.h"
 
 #include <main/entorno.h>
 #include <main/controllers/controladorvistas.h>
@@ -70,6 +71,11 @@ namespace GNC {
 			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
 			m_MapaPasos[id.m_pItem] = pPaso;
 
+			pPaso = new LocalDatabaseConfigurationPanel(m_pPanelConfig,this);
+			pPaso->GetPanel()->Hide();
+			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
+			m_MapaPasos[id.m_pItem] = pPaso;
+
 			pPaso = new PanelConfiguracionHCE(m_pPanelConfig,this);
 			pPaso->GetPanel()->Hide();
 			id = m_pTreeNavegacion->AppendItem(ginkgo,wxString::FromUTF8(pPaso->GetTitle().c_str()));
