@@ -3,7 +3,7 @@
 *  $Id: panelconfiguracionpermisos.cpp $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -28,6 +28,7 @@
 #include <wx/pen.h>
 #include <wx/pen.h>
 #include <wx/sizer.h>
+#include <wx/msgdlg.h>
 #include <wx/aui/auibar.h>
 #include <wx/menu.h>
 #include "hangingprotocolconfigurationpanel.h"
@@ -37,6 +38,10 @@
 #define COL_CRITERIA_VALUE			1
 #define COL_CRITERIA_ID				2
 
+#define COL_LABEL_ID				0
+#define COL_WINDOW_ID				1
+#define COL_LEVEL_ID				2
+
 namespace GNC {
 	namespace GUI {
 		//////////////////////////////////////////
@@ -158,10 +163,18 @@ namespace GNC {
 		class EditCriteriaPanel: public EditCriteriaPanelBase
 		{
 		public:
-			EditCriteriaPanel(wxWindow* pParent): EditCriteriaPanelBase(pParent)
+			EditCriteriaPanel(wxWindow* pParent, bool buttonsRight = true): EditCriteriaPanelBase(pParent)
 			{
+				if (!buttonsRight) {
+					m_pGeneralSizer->SetOrientation(wxVERTICAL);
+					m_pButtonSizer->SetOrientation(wxHORIZONTAL);
+					m_pButtonSizer->Insert(0, 0, 0, 1, wxEXPAND, 5 );
+					m_pTreeListCriteria->SetColumnWidth(0,100);
+					m_pTreeListCriteria->SetColumnWidth(1,200);
+				}
 				m_pTreeListCriteria->AddRoot(wxT("Root"));
 				m_pTreeListCriteria->Connect(wxEVT_COMMAND_TREE_SEL_CHANGED, wxTreeEventHandler( EditCriteriaPanel::OnCriteriaChangeSelection ), NULL, this );
+				Layout();
 			}
 			~EditCriteriaPanel()
 			{
@@ -260,7 +273,7 @@ namespace GNC {
 						if (seriesMatcher.IsValid()) {
 							this->seriesMatcher = seriesMatcher;
 						} else {
-							this->seriesMatcher = new GNC::GCS::Matcher();
+							this->seriesMatcher = GNC::GCS::Ptr<GNC::GCS::Matcher>(new GNC::GCS::Matcher());
 							this->seriesMatcher->getMatchingCriteria()[GKDCM_SeriesDescription] =  "";
 							this->seriesMatcher->getMatchingCriteria()[GKDCM_Modality] =  "";
 						}
@@ -399,9 +412,9 @@ namespace GNC {
 					{
 						this->hangingSupportLevel = hsl;
 
-						editSeriesCriteriaPanel = new EditCriteriaPanel(m_panelSeriesCriteria);
+						editSeriesCriteriaPanel = new EditCriteriaPanel(m_pLayoutPreview, false);
 						m_pSizerSeriesCriteria->Add(editSeriesCriteriaPanel, 1, wxEXPAND|wxALL, 5);
-						m_panelSeriesCriteria->Layout();
+						m_pLayoutPreview->Layout();
 
 						m_pSpinCols->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1);
 						m_pSpinRows->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1);
@@ -437,7 +450,7 @@ namespace GNC {
 					/**
 					IHangingProtocolContract
 					*/
-					virtual wxWindow* createSeriesViewer(const std::map<std::string, std::string>& /*properties*/, long /*pk = -1*/, const GNC::GCS::Ptr<GNC::GCS::Matcher>& matcher)
+					virtual wxWindow* createSeriesSlot(const std::map<std::string, std::string>& /*properties*/, long /*pk = -1*/, const GNC::GCS::Ptr<GNC::GCS::Matcher>& matcher)
 					{
 						listPreviewLayouts.push_back(new PreviewLayoutPanel(this, m_pLayoutPreview, matcher));
 						return listPreviewLayouts.back();
@@ -500,7 +513,7 @@ namespace GNC {
 						pItem->SetSizer(pNewSizer);
 						pNewSizer->Add(selectedPreview, 1, wxEXPAND|wxALL);
 						std::map<std::string, std::string> prop;
-						pNewSizer->Add(createSeriesViewer(prop, -1, NULL), 1, wxEXPAND|wxALL);
+						pNewSizer->Add(createSeriesSlot(prop, -1, NULL), 1, wxEXPAND|wxALL);
 						m_pLayoutPreview->Layout();
 						m_pLayoutPreview->Thaw();
 					}			
@@ -584,6 +597,178 @@ namespace GNC {
 					std::list<PreviewLayoutPanel*> listPreviewLayouts;
 					GNC::GCS::ModoControlador::T_HangingProtocolSupportLevel hangingSupportLevel;
 				};//end StudyWindow
+
+			class ModalityPanel: public ModalityPanelBase
+			{
+			public:
+				class AddWindowLevelDialog: public AddWLDialogBase
+				{
+				public:
+					AddWindowLevelDialog(ModalityPanel* pParent): AddWLDialogBase(pParent),
+						Parent(pParent), 
+						EditMode(false)
+					{
+					}
+
+					AddWindowLevelDialog(ModalityPanel* pParent, const wxString& label, const wxString& window, const wxString& level): 
+						AddWLDialogBase(pParent),
+						Parent(pParent),
+						EditMode(true)
+					{
+						m_pLabel->SetValue(label);
+						m_pWindow->SetValue(window);
+						m_pLevel->SetValue(level);
+					}
+
+					virtual bool Validate()
+					{
+						if (m_pLabel->GetValue().empty() || m_pWindow->GetValue().empty() || m_pLevel->GetValue().empty()) {
+							wxMessageBox(_("You must fill in all fields"),_("Info"),wxOK | wxICON_INFORMATION, this);
+							return false;
+						} else {
+							double window, level;
+							if (m_pWindow->GetValue().ToDouble(&window) && m_pLevel->GetValue().ToDouble(&level)) {
+								if (!EditMode && Parent->m_pDefaultWindowLevel->FindString(m_pLabel->GetValue()) > 0) {
+									wxMessageBox(_("Window/level label in use"),_("Info"),wxOK | wxICON_INFORMATION, this);
+									return false;
+								}
+								return true;
+							} else {
+								wxMessageBox(_("Fill in valid numbers in window and level fields."),_("Info"),wxOK | wxICON_INFORMATION, this);
+								return false;
+							}
+						}
+					}
+
+					ModalityPanel* Parent;
+					bool EditMode;
+				};
+
+
+				ModalityPanel(wxWindow* pParent, const GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings>& lo): ModalityPanelBase(pParent),
+						modSettings(lo)
+				{
+				}
+
+				void InitPanels()
+				{
+					
+					wxTreeItemId idRoot = m_pWLList->AddRoot(wxT("Root"));
+					for (GNC::GCS::DefaultModalitySettings::TListOfWLSettings::const_iterator it = modSettings->getWLSettings().begin(); it != modSettings->getWLSettings().end(); ++it)
+					{
+						wxTreeItemId idItem = m_pWLList->AppendItem(m_pWLList->GetRootItem(),wxString::FromUTF8((*it)->getLabel().c_str()));
+						m_pWLList->SetItemText(idItem, COL_WINDOW_ID, wxString::Format(wxT("%.2lf"), (*it)->getWindow()));
+						m_pWLList->SetItemText(idItem, COL_LEVEL_ID, wxString::Format(wxT("%.2lf"), (*it)->getLevel()));
+					}
+					RebuildComboWL();
+					m_pChoiceInterpolate->Append(_("Nearest neighbour"));
+					m_pChoiceInterpolate->Append(_("Linear"));
+					m_pChoiceInterpolate->Append(_("Cubic"));
+					if (modSettings->getInterpolationMode() == GNC::GCS::DefaultModalitySettings::TIM_NEAREST_NEIGHBOUR) {
+						m_pChoiceInterpolate->Select(0);
+					} else if (modSettings->getInterpolationMode() == GNC::GCS::DefaultModalitySettings::TIM_LINEAR) {
+						m_pChoiceInterpolate->Select(1);
+					}  else if (modSettings->getInterpolationMode() == GNC::GCS::DefaultModalitySettings::TIM_CUBIC) {
+						m_pChoiceInterpolate->Select(2);
+					}
+				}
+
+				void RebuildComboWL()
+				{
+					m_pDefaultWindowLevel->Clear();
+					m_pDefaultWindowLevel->Append(wxString::FromUTF8(GNC::GCS::DefaultModalitySettings::getDefaultWindowLevelLabel().c_str()));
+					m_pDefaultWindowLevel->Append(wxString::FromUTF8(GNC::GCS::DefaultModalitySettings::getAutocalculateWindowLevelLabel().c_str()));
+					m_pDefaultWindowLevel->Select(0);
+					if (modSettings->getInitialWindowLevelLabel() == GNC::GCS::DefaultModalitySettings::getAutocalculateWindowLevelLabel()) {
+						m_pDefaultWindowLevel->Select(1);
+					}
+					for (GNC::GCS::DefaultModalitySettings::TListOfWLSettings::const_iterator it = modSettings->getWLSettings().begin(); it != modSettings->getWLSettings().end(); ++it)
+					{
+						int item = m_pDefaultWindowLevel->Append(wxString::FromUTF8((*it)->getLabel().c_str()));
+						if ((*it)->getLabel() == modSettings->getInitialWindowLevelLabel()) {
+							m_pDefaultWindowLevel->Select (item); 
+						}
+					}
+				}
+
+				const std::string& getModalityName() 
+				{
+					return modSettings->getModality();
+				}
+
+				virtual void OnAddWL(wxCommandEvent& /*evt*/) 
+				{
+					AddWindowLevelDialog dlg(this);
+					if (dlg.ShowModal() == wxID_OK) {
+						m_pDefaultWindowLevel->Append(dlg.m_pLabel->GetValue());
+
+						wxTreeItemId idItem = m_pWLList->AppendItem(m_pWLList->GetRootItem(),dlg.m_pLabel->GetValue());
+						m_pWLList->SetItemText(idItem, COL_WINDOW_ID, dlg.m_pWindow->GetValue());
+						m_pWLList->SetItemText(idItem, COL_LEVEL_ID, dlg.m_pLevel->GetValue());
+					}
+				}
+
+				virtual void OnEditWL(wxCommandEvent& /*evt*/) 
+				{
+					wxTreeItemId item = m_pWLList->GetSelection();
+					if (item.IsOk()) {
+						wxString oldLabel = m_pWLList->GetItemText(item, COL_LABEL_ID);
+						wxString oldWindow = m_pWLList->GetItemText(item, COL_WINDOW_ID);
+						wxString oldLevel = m_pWLList->GetItemText(item, COL_LEVEL_ID);
+						AddWindowLevelDialog dlg(this, oldLabel, oldWindow, oldLevel);
+						if (dlg.ShowModal() == wxID_OK) {
+							int comboItem = m_pDefaultWindowLevel->FindString(oldLabel);
+							if (comboItem > 0) {
+								m_pDefaultWindowLevel->SetString(comboItem, dlg.m_pLabel->GetValue());
+							}
+							m_pWLList->SetItemText(item, COL_LABEL_ID, dlg.m_pLabel->GetValue());
+							m_pWLList->SetItemText(item, COL_WINDOW_ID, dlg.m_pWindow->GetValue());
+							m_pWLList->SetItemText(item, COL_LEVEL_ID, dlg.m_pLevel->GetValue());
+						}
+					}
+				}
+
+				virtual void OnDeleteWL(wxCommandEvent& /*evt*/)
+				{
+					wxTreeItemId item = m_pWLList->GetSelection();
+					if (item.IsOk()) {
+						int answer = wxMessageBox(_("Do you confirm the removal of the preset?"), _("Data modified"), wxYES_NO | wxCANCEL, this);
+						if(answer == wxYES){
+							wxString oldLabel = m_pWLList->GetItemText(item, COL_LABEL_ID);
+							int comboItem = m_pDefaultWindowLevel->FindString(oldLabel);
+							if (comboItem > 0) {
+								m_pDefaultWindowLevel->Delete(comboItem);
+								if (m_pDefaultWindowLevel->GetSelection() < 0) {
+									m_pDefaultWindowLevel->Select(0);
+								}
+							}
+							m_pWLList->Delete(item);
+						}
+					}
+				}
+
+				GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> GetSettings()
+				{
+					modSettings->clearWindowLevels();
+					modSettings->setInitialWindowLevelLabel(std::string(m_pDefaultWindowLevel->GetString(m_pDefaultWindowLevel->GetSelection()).ToUTF8()));
+
+					wxTreeItemIdValue cookie;
+					for (wxTreeItemId item = m_pWLList->GetFirstChild(m_pWLList->GetRootItem(), cookie); item.IsOk(); item = m_pWLList->GetNextChild(m_pWLList->GetRootItem(), cookie))
+					{
+						double window;
+						double level;
+						if (m_pWLList->GetItemText(item, COL_WINDOW_ID).ToDouble(&window) && m_pWLList->GetItemText(item, COL_LEVEL_ID).ToDouble(&level)) {
+							GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(window, level, std::string(m_pWLList->GetItemText(item, COL_LABEL_ID).ToUTF8())));
+							modSettings->addWindowLevel(wlSettings);
+						}
+					}
+
+					modSettings->setInterpolationMode((GNC::GCS::DefaultModalitySettings::TInterpolationMode)m_pChoiceInterpolate->GetSelection());
+					return modSettings;
+				}
+
+				GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> modSettings;
+			};
 		public:
 			EditHangingProtocolDialog(wxWindow* pParent): EditHangingProtocolDialogBase(pParent)
 			{	
@@ -602,7 +787,8 @@ namespace GNC {
 				if (!hangingProtocol.IsValid()) {
 					SelectOpeningMode dlg(this->GetParent());
 					if (dlg.ShowModal() == wxID_OK) {
-						hangingProtocol = new GNC::GCS::HangingProtocol();
+						hangingProtocol = GNC::GCS::Ptr<GNC::GCS::HangingProtocol>(new GNC::GCS::HangingProtocol());
+						hangingProtocol->setName(_Std("New hanging protocol"));
 						hangingProtocol->setModuleSid(dlg.GetModuloSeleccionado()->GetUID());
 						hangingProtocol->setOpeningMode(dlg.GetModoSeleccionado()->GetId());
 						//basic criteria...
@@ -624,6 +810,8 @@ namespace GNC {
 
 			void InitPanels()
 			{
+				m_currentModality = NULL;
+
 				editStudyCriteriaPanel = new EditCriteriaPanel(m_pGeneralPanel);
 				m_pSizerStudyCriteria->Add(editStudyCriteriaPanel, 1, wxEXPAND|wxALL, 5);
 
@@ -643,25 +831,38 @@ namespace GNC {
 				{
 					if ((*it).IsValid()) {
 						StudyWindow* sw = new StudyWindow(m_pNoteBookWindows, (*it));
-						m_pNoteBookWindows->AddPage(sw, wxString::Format(_("Window %d"), m_pNoteBookWindows->GetPageCount()));
+						m_pNoteBookWindows->InsertPage(m_pNoteBookWindows->GetPageCount() - 1, sw, wxString::Format(_("Window %d"), m_pNoteBookWindows->GetPageCount()));
 						sw->InitPanels(hangingSupportLevel);
 					}
-				}								
-
-				m_pAddButton->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1);
-				m_pBDelete->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1 && m_pNoteBookWindows->GetPageCount() > 1);
+				}	
+				m_pNoteBookWindows->SetSelection(0);
 
 				m_textName->SetValue(wxString::FromUTF8(hangingProtocol->getName().c_str()));
-				this->editStudyCriteriaPanel->loadMatcher(hangingProtocol->getStudyMatcher());			
+				this->editStudyCriteriaPanel->loadMatcher(hangingProtocol->getStudyMatcher());	
+
+				//default modality settings...
+				wxTreeItemId root = m_pTreeNavigation->AddRoot(_("Modalities"));
+				for (GNC::GCS::HangingProtocol::TMapOfModalitySettings::const_iterator it = hangingProtocol->getModalitySettingsMap().begin(); it != hangingProtocol->getModalitySettingsMap().end(); ++it)
+				{
+					if ((*it).second.IsValid()) {
+						ModalityPanel * mp = new ModalityPanel(m_pModalityPanel, (*it).second);
+						wxTreeItemId id = m_pTreeNavigation->AppendItem(root, wxString::FromUTF8(mp->getModalityName().c_str()));
+						modalityBrowser[id.m_pItem] = mp;
+						mp->InitPanels();
+						mp->Hide();
+						m_pSizerModalities->Add(mp, 1, wxEXPAND|wxALL, 5);
+						m_pModalityPanel->Layout();
+					}
+				}
+				wxTreeItemIdValue cookie;
+				m_pTreeNavigation->SelectItem(m_pTreeNavigation->GetFirstChild(root, cookie));
+				LoadCurrent();
+				//
 
 				m_pNoteBookWindows->Layout();
 				m_pGeneralPanel->Layout();
-				m_pBody->Layout();
+				m_pMainNoteBook->Layout();
 				Layout();
-
-				int ySize = 0;
-				ySize = m_pGeneralPanel->GetSize().x;
-				m_pBody->SetVirtualSize(-1, ySize);
 			}
 
 			GNC::GCS::Ptr<GNC::GCS::HangingProtocol>& getHangingProtocol()
@@ -681,34 +882,89 @@ namespace GNC {
 						}
 					}
 				}
+				this->hangingProtocol->clearModalitySettings();
+				for (wxWindowList::iterator it = m_pModalityPanel->GetChildren().begin(); it != m_pModalityPanel->GetChildren().end(); ++it) {
+					ModalityPanel* mp = dynamic_cast<ModalityPanel*>((*it));
+					if (mp != NULL) {
+						GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings> settings = mp->GetSettings();
+						if (settings.IsValid()) {
+							this->hangingProtocol->addModalitySettings(settings);
+						}
+					}
+				}
 				return this->hangingProtocol;
 			}
 
 
 		protected:
-			virtual void OnAddStudyWindowClick(wxCommandEvent &)
-			{
-				Freeze();
-				StudyWindow* sw = new StudyWindow(m_pNoteBookWindows);
-				m_pNoteBookWindows->AddPage(sw, wxString::Format(_("Window %d"), m_pNoteBookWindows->GetPageCount()), true);
-				sw->InitPanels(hangingSupportLevel);
-				m_pBDelete->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1 && m_pNoteBookWindows->GetPageCount() > 1);
-				Thaw();
+			void OnNavigationChanged(wxTreeEvent &){
+				LoadCurrent();
 			}
 
-			virtual void OnDeleteStudyWindowClick(wxCommandEvent &)
+			void LoadCurrent() 
 			{
-				if (m_pNoteBookWindows->GetPageCount() > 1) {
-					Freeze();
-					m_pNoteBookWindows->DeletePage(m_pNoteBookWindows->GetSelection());
-					Thaw();
+				wxTreeItemId id = m_pTreeNavigation->GetSelection();
+				if (id.IsOk()) {
+					if(modalityBrowser.find(id.m_pItem) != modalityBrowser.end()){
+						ModalityPanel* pCurrent = modalityBrowser[id.m_pItem];
+						if( pCurrent!=NULL && pCurrent!=m_currentModality){
+							m_pTitledPanelModalities->Freeze();
+							if(m_currentModality!=NULL){
+								m_currentModality->Hide();
+							}
+							m_currentModality = pCurrent;
+							wxString modName = wxString::Format(_("%s settings"),wxString::FromUTF8(pCurrent->getModalityName().c_str()).c_str());
+							m_pTitledPanelModalities->SetToolTip(modName);
+							m_currentModality->Show();
+							m_pModalityPanel->SetScrollbars(20, 20, 50, 50, 0, 0, false);
+							m_pModalityPanel->AdjustScrollbars();
+							m_pTitledPanelModalities->Layout();
+							m_pTitledPanelModalities->Thaw();					
+						}
+					}
+				}
+			}			
+
+			virtual void OnPageChanging( wxAuiNotebookEvent& event ) 
+			{
+				if (event.selection == ((int)m_pNoteBookWindows->GetPageCount() -1)) {
+					if (event.old_selection < 0) {
+						//if comes from page closing
+						m_pNoteBookWindows->SetSelection(m_pNoteBookWindows->GetPageCount() - 2);
+					} else {
+						if (hangingSupportLevel == GNC::GCS::ModoControlador::THSL_FULL) {
+							m_pWorkspacePanel->Freeze();
+							StudyWindow* sw = new StudyWindow(m_pNoteBookWindows);
+							m_pNoteBookWindows->InsertPage(m_pNoteBookWindows->GetPageCount() - 1,sw, wxString::Format(_("Window %d"), m_pNoteBookWindows->GetPageCount()), true);
+							sw->InitPanels(hangingSupportLevel);
+							m_pNoteBookWindows->Layout();
+							m_pWorkspacePanel->Thaw();
+						} else {
+							wxMessageBox(_("This view doesn't support multiple windows"),_("Info"),wxOK | wxICON_INFORMATION, this);
+						}
+					}
+					event.Veto();
+				} else {
+					event.Skip();
 				}
-				m_pBDelete->Enable(hangingSupportLevel != GNC::GCS::ModoControlador::THSL_ONLY_1x1 && m_pNoteBookWindows->GetPageCount() > 1);
 			}
 
+			virtual void OnPageClose( wxAuiNotebookEvent& event )
+			{
+				if (m_pNoteBookWindows->GetPageCount() <= 2) {
+					event.Veto();
+				} else {
+					event.Skip();
+				}
+			}
+
+
 			GNC::GCS::ModoControlador::T_HangingProtocolSupportLevel hangingSupportLevel;
 			EditCriteriaPanel* editStudyCriteriaPanel;	
 			GNC::GCS::Ptr<GNC::GCS::HangingProtocol> hangingProtocol;	
+			typedef std::map<wxTreeItemIdValue ,ModalityPanel*> TModalityMap;
+			TModalityMap modalityBrowser;
+			ModalityPanel* m_currentModality;
 		};
 		////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 		class wxTreeItemDataProtocols: public wxTreeItemData
@@ -869,7 +1125,8 @@ namespace GNC {
 					} else {
 						m_pTreeListProtocols->SetItemText(item, 1, _("No"));
 					}
-					m_pTreeListProtocols->SetItemData(item, new wxTreeItemDataProtocols(hp));
+					m_pTreeListProtocols->SetItemText(item, 0, wxString::FromUTF8(hp->getName().c_str()));
+					((wxTreeItemDataProtocols*)m_pTreeListProtocols->GetItemData(item))->hangingProtocol = hp;
 					OnPropiedadCambiada();
 				}
 			}
