@@ -3,7 +3,7 @@
  *  $Id: wxwizardimportacionginkgo.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -32,16 +32,20 @@
 #include <main/gui/progress/statusbarprogreso.h>
 #include <resources/ginkgoresourcesmanager.h>
 #include <main/controllers/controladoreventos.h>
+#include <main/controllers/windowattributescontroller.h>
 
 #include <vector>
 #include <sstream>
 
-
+#define DICOMIZE_WIZARD_ID "DicomizeWizard"
 
 namespace GNC {
 	namespace GUI {
 		wxWizardImportacionGinkgo::wxWizardImportacionGinkgo(wxWindow* pParent, GNC::GCS::Ptr<GIL::IModeloIntegracion> pModeloIntegracion, std::string uidModulo) : wxWizardGinkgoBase(pParent)
 		{
+			//load attributes
+			GNC::GCS::WindowAttributesController::LoadWindowAttributes(DICOMIZE_WIZARD_ID, this, false);
+			//
 			wxWindowDisabler disabler;
 			SetTitle(_("Image Import Wizard"));
 			m_pModeloIntegracion = pModeloIntegracion;
@@ -116,9 +120,11 @@ namespace GNC {
 					//////////TODOm_pModeloIntegracion->UIDModulo = m_pControladorModulo->GetUID();
 				}
 
-				for(std::list<IPasoWizard*>::iterator it=pasosModulo.begin();it!=pasosModulo.end();++it){
-					m_ListaPasos.push_back(*it);
-					(*it)->AsignarListaFicheros(m_ListaFicheros);
+				for(std::list<IPasoWizard*>::iterator it=pasosModulo.begin();it!=pasosModulo.end();++it) {
+					if (!(*it)->IsSkipped()) {
+						m_ListaPasos.push_back(*it);
+						(*it)->AsignarListaFicheros(m_ListaFicheros);
+					}
 				}
 				//
 			} else {
@@ -183,6 +189,9 @@ namespace GNC {
 		wxWizardImportacionGinkgo::~wxWizardImportacionGinkgo()
 		{
 			m_ListaPasos.clear();
+			
+			//save window attributes
+			GNC::GCS::WindowAttributesController::SaveWindowAttributes(DICOMIZE_WIZARD_ID, this);
 		}
 		
 		void  wxWizardImportacionGinkgo::BorrarArchivosTemporales()
@@ -235,7 +244,8 @@ namespace GNC {
 		
 		void wxWizardImportacionGinkgo::OnSiguienteClick(wxCommandEvent&)
 		{
-			if((*m_currentPaso)->Validar()){
+			if ((*m_currentPaso)->Validar()) 
+			{
 				Freeze();
 				
 				wxWindow* pCurrent = dynamic_cast<wxWindow*> (*m_currentPaso);
@@ -258,16 +268,20 @@ namespace GNC {
 ////////TODO				m_pModeloIntegracion->UIDModulo = m_pControladorModulo->GetUID();
 						}
 						
-						for(std::list<IPasoWizard*>::iterator it=pasosModulo.begin();it!=pasosModulo.end();++it){
-							m_ListaPasos.push_back(*it);
-							(*it)->AsignarListaFicheros(m_ListaFicheros);
+						for(std::list<IPasoWizard*>::iterator it=pasosModulo.begin();it!=pasosModulo.end();++it) {
+							if (!(*it)->IsSkipped()) {
+								m_ListaPasos.push_back(*it);
+								(*it)->AsignarListaFicheros(m_ListaFicheros);
+							}
 						}
 						
 						m_currentPaso = m_ListaPasos.begin();
 						m_currentPasoIndex=1;
 					} else {
-						++m_currentPasoIndex;
-						++m_currentPaso;
+						do {
+							++m_currentPasoIndex;
+							++m_currentPaso;
+						} while ((m_currentPaso != m_ListaPasos.end() && (*m_currentPaso)->IsSkipped()));
 					}
 					
 					if(m_currentPaso==m_ListaPasos.end()){
