@@ -3,7 +3,7 @@
  *  $Id: widgetsmanager.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -159,7 +159,7 @@ void GNC::WidgetsManager::RenderPrivate(GNC::GCS::Contexto3D* c)
 	// Primera pasada: widgets normales.
 	for (IteradorListaWidgets it = m_Widgets.begin(); it != m_Widgets.end(); ++it) {
 		GNC::GCS::Widgets::IWidget* w = *it;
-		if (!w->EsTopLevel() && (w->GetVID() == c->GetRenderer()->GetVID()) ) {
+		if (!w->EsTopLevel() && (w->GetVID() == c->GetRenderer()->GetVID() || w->GetVID() == -1) ) {
 			w->Render(c);
 			w->Modificar(false);
 		}
@@ -767,6 +767,33 @@ void GNC::WidgetsManager::RemoveAllWidgetsExceptTID(long tid, bool propagateEven
 	}
 }
 
+void GNC::WidgetsManager::RemoveUserAnnotationWidgets(bool propagateEvents)
+{
+	GNC::GCS::ListaWidgets lw;
+	for (IteradorListaWidgets it = m_Widgets.begin(); it != m_Widgets.end(); ++it) {
+		GNC::GCS::Widgets::IWidget* w = (*it);
+		if (w != NULL && w->GetTID() == TID_USER_ANNOTATION_WIDGET) {
+			lw.push_back(w);
+		}
+	}
+	for (IteradorListaWidgets it = lw.begin(); it != lw.end(); ++it) {
+		GNC::GCS::Widgets::IWidget* w = (*it);
+		if (propagateEvents) {
+			NotificarDestruccion(w);
+		}
+		if(w->ReservaRecursos()) {
+			for (GNC::GCS::ListaRenderers::iterator itr = m_Renderers.begin(); itr != m_Renderers.end(); ++itr)
+			{
+				GNC::GCS::IWidgetsRenderer* pRenderer = *itr;
+				pRenderer->WSetCurrent();
+				w->LiberarRecursos(pRenderer);
+			}
+		}
+		m_Widgets.remove(w);
+		delete w;
+	}
+}
+
 void GNC::WidgetsManager::EliminarTodosLosWidgets(bool propagarEventos)
 {
 	for (IteradorListaWidgets it = m_Widgets.begin(); it != m_Widgets.end(); ++it) {
@@ -1118,6 +1145,9 @@ void GNC::WidgetsManager::SetCursor(GNC::GCS::Widgets::TipoCursor cursor)
 				case GNC::GCS::Widgets::CUR_ANCLA_COMPUESTA:
 					(*itr)->m_c->pWindow->SetCursor(wxCursor(GinkgoResourcesManager::Cursors::GetCursorAnclaCompuesta()));
 					break;
+				case GNC::GCS::Widgets::CUR_ROTATION:
+					(*itr)->m_c->pWindow->SetCursor(wxCursor(GinkgoResourcesManager::Cursors::GetRotationCursor()));
+					break;
 				case GNC::GCS::Widgets::CUR_INVALIDO:
 					break;
 			}
