@@ -3,7 +3,7 @@
 *  $Id: wanotacionesquina.cpp $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -45,6 +45,7 @@
 #include <vtkImageActor.h>
 #include <vtkPointData.h>
 #include <vtk/vtkginkgoimageviewer.h>
+#include "striptexthelper.h"
 
 
 #define ANNOTATOR_TEXT_COLOR 0.9f, 0.9f, 0.9f, 1.0f
@@ -69,47 +70,104 @@ namespace GNC {
 		namespace Widgets {
 
 			//----------------------------------------------------------------------------------------------------
+			class OrientationMarks
+			{
+				public:
+					typedef enum TOrientationPosition {
+						TP_Top,
+						TP_Right,
+						TP_Bottom,
+						TP_Left,
+						TP_NumPosiciones
+					} TPosicionAnotacion;
+				OrientationMarks() {
+					m_StripTextRenderer.Update("RLAPIS", GNC::GCS::GLHelper::TColor(ANNOTATOR_TEXT_COLOR), TAMFUENTE);
+				}
+
+				~OrientationMarks()
+				{
+				}
+
+				bool SetAnotation(TOrientationPosition index, const std::string& str)
+				{
+					if (m_TextoAnotacion[index] != str) {
+						m_TextoAnotacion[index] = str;
+						return true;
+					}
+					else {
+						return false;
+					}
+				}
+
+
+				void Render(GNC::GCS::Contexto3D* /*c*/, GNC::GCS::Vector m_RectViewport[2])
+				{
+					GNC::GCS::Vector pos;
+					//
+					pos = GNC::GCS::Vector( (0.5 * m_RectViewport[1].x), 2.0).Redondeado();
+					m_StripTextRenderer.Render(m_TextoAnotacion[OrientationMarks::TP_Top], pos, true);
+
+					pos = GNC::GCS::Vector(10.0, (0.5 * m_RectViewport[1].y)).Redondeado();
+					m_StripTextRenderer.Render(m_TextoAnotacion[OrientationMarks::TP_Left], pos, true);
+
+					pos = GNC::GCS::Vector((0.5 * m_RectViewport[1].x), m_RectViewport[1].y - m_StripTextRenderer.GetTextHeigh() - 10.0 ).Redondeado();
+					m_StripTextRenderer.Render(m_TextoAnotacion[OrientationMarks::TP_Bottom], pos, true);
+
+					pos = GNC::GCS::Vector( m_RectViewport[1].x - 4.0,  (0.5 * m_RectViewport[1].y) ).Redondeado();
+					m_StripTextRenderer.Render(m_TextoAnotacion[OrientationMarks::TP_Right], pos, false);
+					//
+				}
+				void LiberarRecursos()
+				{
+					m_StripTextRenderer.Destroy();
+				}
+
+				std::string m_TextoAnotacion[4];
+				GNC::GCS::Widgets::StripTextRenderer m_StripTextRenderer;
+			};
+
 			class Anotaciones {
 			public:
+				typedef enum TPosicionAnotacion {
+					TP_TopLeft = 0,
+					TP_TopRight,
+					TP_BottomLeft,
+					TP_BottomRight,
+					TP_NumPosiciones
+				} TPosicionAnotacion;
 
-				inline Anotaciones(GNC::GCS::IWidgetsRenderer* pRenderer)
+				Anotaciones(GNC::GCS::IWidgetsRenderer* pRenderer)
 				{
 					m_TamFuente           = TAMFUENTE;
 					m_Correcta            = false;
 					m_RecalcularTamOptimo = false;
 					m_pRenderer           = pRenderer;
 					m_Modificada          = false;
-					for (int i = 0; i < WAnotador::TP_NumPosiciones; i++)
+					for (int i = 0; i < Anotaciones::TP_NumPosiciones; i++)
 					{
 						m_TexturaModificada[i] = false;
 					}
 
-					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_TopLeft] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
-					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_TopRight] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
-					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_BottomLeft] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
-					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_BottomRight] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
-
-					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_Top] = GNC::GCS::Widgets::HelperTexto::TA_Centrado;
-					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_Right] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
-					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_Bottom] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
-					m_Alineacion[GNC::GCS::Widgets::WAnotador::TP_Left] = GNC::GCS::Widgets::HelperTexto::TA_Centrado;
+					m_Alineacion[Anotaciones::TP_TopLeft] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
+					m_Alineacion[Anotaciones::TP_TopRight] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
+					m_Alineacion[Anotaciones::TP_BottomLeft] = GNC::GCS::Widgets::HelperTexto::TA_Izquierda;
+					m_Alineacion[Anotaciones::TP_BottomRight] = GNC::GCS::Widgets::HelperTexto::TA_Derecha;
 
 					m_pFontOptions = cairo_font_options_create();
 					m_TexturaMetrica.Redimensionar(2, 2);
 					cairo_get_font_options(m_TexturaMetrica.cr, m_pFontOptions);
 					cairo_font_options_set_antialias (m_pFontOptions, CAIRO_ANTIALIAS_NONE);
 					cairo_set_font_options(m_TexturaMetrica.cr, m_pFontOptions);
-					//std::cout << "Creados recursos de " << m_pRenderer << std::endl;
 				}
 
-				inline ~Anotaciones()
+				~Anotaciones()
 				{
 					cairo_font_options_destroy(m_pFontOptions);
 					m_pFontOptions = NULL;
 					//std::cout << "Destruyendo recursos de " << m_pRenderer << std::endl;
 				}
 
-				inline void Redimensionar(double* viewport)
+				void Redimensionar(double* viewport)
 				{
 					bool redimensionado = false;
 					if (m_RectViewport[0].x != viewport[0])
@@ -135,15 +193,13 @@ namespace GNC {
 					if (redimensionado) {
 						m_TamViewPort = (m_RectViewport[1] - m_RectViewport[0]).ValorAbsoluto() * PROPVIEWPORT;
 						m_RecalcularTamOptimo = true;
-						GTRACE("Anotaciones::Redimensionar( [ " << m_RectViewport[0] << ", " << m_RectViewport[1] << " ] )");
 					}
 				}
 
 			public:
 
-				inline void ModificarTextura(int i, bool modificada)
+				void ModificarTextura(int i, bool modificada)
 				{
-					GTRACE("Anotaciones::ModificarTextura( " << i << " )");
 					m_TexturaModificada[i] = modificada;
 					if (modificada) {
 						Modificar(true);
@@ -152,7 +208,7 @@ namespace GNC {
 
 				}
 
-				inline void Modificar(bool modificada)
+				void Modificar(bool modificada)
 				{
 					m_Modificada = modificada;
 					if (m_Modificada) {
@@ -160,15 +216,14 @@ namespace GNC {
 					}
 				}
 
-				inline bool EstaModificada()
+				bool EstaModificada()
 				{
 					return m_Modificada;
 				}
 
-				inline bool SetAnotation(WAnotador::TPosicionAnotacion index, const std::string& str)
+				bool SetAnotation(TPosicionAnotacion index, const std::string& str)
 				{
 					if (m_TextoAnotacion[index] != str) {
-						GTRACE("Anotaciones::SetAnotacion( " << index << " )");
 						m_TextoAnotacion[index] = str;
 						ModificarTextura(index, true);
 						return true;
@@ -178,20 +233,18 @@ namespace GNC {
 					}
 				}
 
-				inline void RecalcularTamOptimo()
+				void RecalcularTamOptimo()
 				{
 					if (m_RecalcularTamOptimo) {
-						GTRACE("Anotaciones::RecalcularTamOptimo()");
 						m_RecalcularTamOptimo = false;
 						m_TamCajaMaxima = m_TamViewPort;
 						m_TamFuente = TAMFUENTE;
-						for (int i = 0; i < WAnotador::TP_NumPosiciones; ++i) {
+						for (int i = 0; i < Anotaciones::TP_NumPosiciones; ++i) {
 							m_TamTexto[i].Asignar(0.0f, 0.0f);
 							if (m_TextoAnotacion[i].size() > 0) {
 								cairo_select_font_face(m_TexturaMetrica.cr, FUENTE_CAIRO, CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
 								cairo_set_font_size(m_TexturaMetrica.cr, TAMFUENTE);
 								m_TamTexto[i] = GNC::GCS::GLHelper::calcularBoundingBox(m_TexturaMetrica, m_TextoAnotacion[i], -1);
-								GTRACE("Anotaciones::RecalcularTamOptimo >> TamTexto[" << i << "] 12.0 = " << m_TamTexto[i]);
 								m_TamCajaMaxima.AsignarMaximos(m_TamTexto[i]);
 							}
 						}
@@ -199,37 +252,33 @@ namespace GNC {
 							m_TamFuente = ((m_TamViewPort * TAMFUENTE) / m_TamCajaMaxima).Redondear().ComponenteMinima(); // Calculo del tamanyo de fuente maxima
 							m_TamFuente = std::max(TAMFUENTE_MIN, m_TamFuente);
 
-							for (int i = 0; i < WAnotador::TP_NumPosiciones; ++i) {
+							for (int i = 0; i < Anotaciones::TP_NumPosiciones; ++i) {
 								m_TamTexto[i] *=  (m_TamFuente / TAMFUENTE);
 								m_TamTexto[i].RedondearAlza();
 								m_Texturas[i].Redimensionar(m_TamTexto[i].x, m_TamTexto[i].y);
 								m_TexturaModificada[i] = true;
-								GTRACE("Anotaciones::RecalcularTamOptimo >> TamTexto[" << i << "] " << m_TamFuente << " = " << m_TamTexto[i]);
 							}
 						}
 						else{
-							for (int i = 0; i < WAnotador::TP_NumPosiciones; ++i) {
+							for (int i = 0; i < Anotaciones::TP_NumPosiciones; ++i) {
 								m_TamTexto[i].RedondearAlza();
 								m_Texturas[i].Redimensionar(m_TamTexto[i].x, m_TamTexto[i].y);
 								m_TexturaModificada[i] = true;
-								GTRACE("Anotaciones::RecalcularTamOptimo >> TamTexto[" << i << "] " << m_TamFuente << " = " << m_TamTexto[i]);
 							}
 						}
 					}
 				}
 
-				inline void Actualizar(const GNC::GCS::GLHelper::TColor& color)
+				void Actualizar(const GNC::GCS::GLHelper::TColor& color)
 				{
 					RecalcularTamOptimo();
 
-					for (int i = 0; i < WAnotador::TP_NumPosiciones; ++i)
+					for (int i = 0; i < Anotaciones::TP_NumPosiciones; ++i)
 					{
-
 						const std::string& texto = m_TextoAnotacion[i];
 
 						if ( m_TexturaModificada[i] && m_Texturas[i].EsValida() && (m_TextoAnotacion[i].size() > 0) )
 						{
-							GTRACE("Anotaciones::Actualizar( " << i << " ) FS = " << m_TamFuente);
 							cairo_select_font_face(m_Texturas[i].cr, FUENTE_CAIRO, CAIRO_FONT_SLANT_NORMAL, CAIRO_FONT_WEIGHT_NORMAL);
 							cairo_set_font_size(m_Texturas[i].cr, m_TamFuente);
 
@@ -238,7 +287,7 @@ namespace GNC {
 							cairo_set_font_options(m_Texturas[i].cr, m_pFontOptions);
 							cairo_set_operator(m_Texturas[i].cr, CAIRO_OPERATOR_SOURCE);
 
-							cairo_set_source_rgba (m_Texturas[i].cr, 0.0f, 0.0f, 0.0f, 0.0f);
+							cairo_set_source_rgba (m_Texturas[i].cr, 1.0f, 1.0f, 0.0f, 0.0f);
 							cairo_paint(m_Texturas[i].cr);
 							m_TamTexto[i] = GNC::GCS::GLHelper::dibujarTexto(m_Texturas[i], texto, color, m_TamCajaMaxima.x, m_Alineacion[i]);
 							m_TexturaModificada[i] = false;
@@ -246,54 +295,34 @@ namespace GNC {
 					}
 				}
 
-				inline void Render(GNC::GCS::Contexto3D* c)
+				void Render(GNC::GCS::Contexto3D* c)
 				{
 					GTRACE("Anotaciones::Render(" << c->GetRenderer() << ")");
 					GNC::GCS::Vector pos;
 
 					pos = GNC::GCS::Vector(0.0, 0.0).Redondeado();
-					m_Texturas[WAnotador::TP_TopLeft].Actualizar();
-					m_Texturas[WAnotador::TP_TopLeft].Render(c, pos, false, false, 0);
+					m_Texturas[Anotaciones::TP_TopLeft].Actualizar();
+					m_Texturas[Anotaciones::TP_TopLeft].Render(c, pos, false, false, 0);
 
-					pos = GNC::GCS::Vector(m_RectViewport[1].x - m_TamTexto[WAnotador::TP_TopRight].x, 0.0).Redondeado();
-					m_Texturas[WAnotador::TP_TopRight].Actualizar();
-					m_Texturas[WAnotador::TP_TopRight].Render(c, pos, false, false, 0);
+					pos = GNC::GCS::Vector(m_RectViewport[1].x - m_TamTexto[Anotaciones::TP_TopRight].x, 0.0).Redondeado();
+					m_Texturas[Anotaciones::TP_TopRight].Actualizar();
+					m_Texturas[Anotaciones::TP_TopRight].Render(c, pos, false, false, 0);
 
-					pos = GNC::GCS::Vector(0.0, m_RectViewport[1].y - m_TamTexto[WAnotador::TP_BottomLeft].y).Redondeado();
-					m_Texturas[WAnotador::TP_BottomLeft].Actualizar();
-					m_Texturas[WAnotador::TP_BottomLeft].Render(c, pos, false, false, 0);
+					pos = GNC::GCS::Vector(0.0, m_RectViewport[1].y - m_TamTexto[Anotaciones::TP_BottomLeft].y).Redondeado();
+					m_Texturas[Anotaciones::TP_BottomLeft].Actualizar();
+					m_Texturas[Anotaciones::TP_BottomLeft].Render(c, pos, false, false, 0);
 
-					pos = GNC::GCS::Vector(m_RectViewport[1].x - m_TamTexto[WAnotador::TP_BottomRight].x, m_RectViewport[1].y - m_TamTexto[WAnotador::TP_BottomRight].y).Redondeado();
-					m_Texturas[WAnotador::TP_BottomRight].Actualizar();
-					m_Texturas[WAnotador::TP_BottomRight].Render(c, pos, false, false, 0);
-
-
-					//
-					pos = GNC::GCS::Vector( (0.5 * m_RectViewport[1].x) - m_TamTexto[WAnotador::TP_Top].x, 0.0).Redondeado();
-					m_Texturas[WAnotador::TP_Top].Actualizar();
-					m_Texturas[WAnotador::TP_Top].Render(c, pos, false, false, 0);
-
-					pos = GNC::GCS::Vector(0.0, (0.5 * m_RectViewport[1].y) - m_TamTexto[WAnotador::TP_Left].y).Redondeado();
-					m_Texturas[WAnotador::TP_Left].Actualizar();
-					m_Texturas[WAnotador::TP_Left].Render(c, pos, false, false, 0);
-
-					pos = GNC::GCS::Vector((0.5 * m_RectViewport[1].x) - m_TamTexto[WAnotador::TP_Bottom].x, m_RectViewport[1].y - m_TamTexto[WAnotador::TP_Bottom].y).Redondeado();
-					m_Texturas[WAnotador::TP_Bottom].Actualizar();
-					m_Texturas[WAnotador::TP_Bottom].Render(c, pos, false, false, 0);
-
-					pos = GNC::GCS::Vector( m_RectViewport[1].x - m_TamTexto[WAnotador::TP_Right].x,  (0.5 * m_RectViewport[1].y) - m_TamTexto[WAnotador::TP_Right].y).Redondeado();
-					m_Texturas[WAnotador::TP_Right].Actualizar();
-					m_Texturas[WAnotador::TP_Right].Render(c, pos, false, false, 0);
-					//
+					pos = GNC::GCS::Vector(m_RectViewport[1].x - m_TamTexto[Anotaciones::TP_BottomRight].x, m_RectViewport[1].y - m_TamTexto[Anotaciones::TP_BottomRight].y).Redondeado();
+					m_Texturas[Anotaciones::TP_BottomRight].Actualizar();
+					m_Texturas[Anotaciones::TP_BottomRight].Render(c, pos, false, false, 0);
 
 					Modificar(false);
-
 				}
 
-				inline void LiberarRecursos()
+				void LiberarRecursos()
 				{
 					GTRACE("Anotaciones::LiberarRecursos()");
-					for (int i = 0; i < WAnotador::TP_NumPosiciones; i++)
+					for (int i = 0; i < Anotaciones::TP_NumPosiciones; i++)
 					{
 						m_Texturas[i].Destruir();
 					}
@@ -306,13 +335,13 @@ namespace GNC {
 
 				GNC::GCS::TexturaCairo m_TexturaMetrica; // Contexto usado solamente para medir.
 
-				bool m_TexturaModificada[WAnotador::TP_NumPosiciones];
+				bool m_TexturaModificada[Anotaciones::TP_NumPosiciones];
 
-				std::string m_TextoAnotacion[WAnotador::TP_NumPosiciones];
+				std::string m_TextoAnotacion[Anotaciones::TP_NumPosiciones];
 
-				GNC::GCS::Vector m_TamTexto[WAnotador::TP_NumPosiciones];
+				GNC::GCS::Vector m_TamTexto[Anotaciones::TP_NumPosiciones];
 
-				GNC::GCS::TexturaCairo m_Texturas[WAnotador::TP_NumPosiciones];
+				GNC::GCS::TexturaCairo m_Texturas[Anotaciones::TP_NumPosiciones];
 
 				bool m_RecalcularTamOptimo;
 
@@ -321,7 +350,7 @@ namespace GNC {
 				bool m_Correcta;
 				float m_TamFuente;
 
-				GNC::GCS::Widgets::HelperTexto::TAlineamiento m_Alineacion[WAnotador::TP_NumPosiciones];
+				GNC::GCS::Widgets::HelperTexto::TAlineamiento m_Alineacion[Anotaciones::TP_NumPosiciones];
 
 				GNC::GCS::IWidgetsRenderer* m_pRenderer;
 				bool m_Modificada;
@@ -333,8 +362,25 @@ namespace GNC {
 			class EstadoInterno {
 			public:
 				typedef std::map<GNC::GCS::IWidgetsRenderer*,Anotaciones*> MapaAnotaciones;
+				typedef std::map<GNC::GCS::IWidgetsRenderer*,OrientationMarks*> OrientationMap;
 
 				MapaAnotaciones       m_Anotaciones;
+				OrientationMap		  m_Orientations;
+
+				inline OrientationMarks* GetOrientation(GNC::GCS::IWidgetsRenderer* key)
+				{
+					OrientationMarks* res = NULL;
+
+					OrientationMap::iterator it = m_Orientations.find(key);
+					if(it != m_Orientations.end()) {
+						res = (*it).second;
+					}
+					else {
+						m_Orientations[key] = res = new OrientationMarks();
+					}
+
+					return res;
+				}
 
 				inline Anotaciones* Get(GNC::GCS::IWidgetsRenderer* key)
 				{
@@ -353,11 +399,21 @@ namespace GNC {
 
 				inline void Delete(GNC::GCS::IWidgetsRenderer* key)
 				{
-					MapaAnotaciones::iterator it = m_Anotaciones.find(key);
-					if(it != m_Anotaciones.end()) {
-						(*it).second->LiberarRecursos();
-						delete (*it).second;
-						m_Anotaciones.erase(it);
+					{
+						MapaAnotaciones::iterator it = m_Anotaciones.find(key);
+						if(it != m_Anotaciones.end()) {
+							(*it).second->LiberarRecursos();
+							delete (*it).second;
+							m_Anotaciones.erase(it);
+						}
+					}
+					{
+						OrientationMap::iterator it = m_Orientations.find(key);
+						if(it != m_Orientations.end()) {
+							(*it).second->LiberarRecursos();
+							delete (*it).second;
+							m_Orientations.erase(it);
+						}
 					}
 				}
 
@@ -475,6 +531,7 @@ bool GNC::GCS::Widgets::WAnotador::HitTest(GNC::GCS::Vector* , int )
 
 
 
+
 void GNC::GCS::Widgets::WAnotador::Render(GNC::GCS::Contexto3D* c)
 {
 	if(m_Oculto){
@@ -500,6 +557,7 @@ void GNC::GCS::Widgets::WAnotador::Render(GNC::GCS::Contexto3D* c)
 	glLoadIdentity();
 
 	Anotaciones* pAnotaciones = m_Estado->Get(c->GetRenderer());
+	OrientationMarks* pOrientation = m_Estado->GetOrientation(c->GetRenderer());
 
 	pAnotaciones->Redimensionar(viewport);
 
@@ -510,21 +568,23 @@ void GNC::GCS::Widgets::WAnotador::Render(GNC::GCS::Contexto3D* c)
 		RecalcularEstaticas(pAnotaciones, c);
 	}
 
+	RecalcularPosicion(pOrientation, c);
+
 	if (!recalc) {
 		for (int i = 0; i < TP_NumPosiciones; ++i) {
 			if (m_volatileProperty[i]) {
 				switch ((WAnotador::TPosicionAnotacion)i) {
 				case TP_TopLeft:
-					pAnotaciones->SetAnotation(TP_TopLeft, m_pAnnotator->GetTopLeftAnnotation(c));
+					pAnotaciones->SetAnotation(Anotaciones::TP_TopLeft, m_pAnnotator->GetTopLeftAnnotation(c));
 					break;
 				case TP_TopRight:
-					pAnotaciones->SetAnotation(TP_TopRight, m_pAnnotator->GetTopRightAnnotation(c));
+					pAnotaciones->SetAnotation(Anotaciones::TP_TopRight, m_pAnnotator->GetTopRightAnnotation(c));
 					break;
 				case TP_BottomLeft:
-					pAnotaciones->SetAnotation(TP_BottomLeft, m_pAnnotator->GetBottomLeftAnnotation(c));
+					pAnotaciones->SetAnotation(Anotaciones::TP_BottomLeft, m_pAnnotator->GetBottomLeftAnnotation(c));
 					break;
 				case TP_BottomRight:
-					pAnotaciones->SetAnotation(TP_BottomRight, m_pAnnotator->GetBottomRightAnnotation(c));
+					pAnotaciones->SetAnotation(Anotaciones::TP_BottomRight, m_pAnnotator->GetBottomRightAnnotation(c));
 					break;
 				case TP_Top:
 					break;
@@ -545,6 +605,7 @@ void GNC::GCS::Widgets::WAnotador::Render(GNC::GCS::Contexto3D* c)
 	pAnotaciones->Actualizar(m_color);
 
 	pAnotaciones->Render(c);
+	pOrientation->Render(c, pAnotaciones->m_RectViewport);
 
 	glPopMatrix();
 
@@ -591,18 +652,30 @@ void GNC::GCS::Widgets::WAnotador::Ocultar(bool oculto)
 void GNC::GCS::Widgets::WAnotador::RecalcularEstaticas(Anotaciones* pAnotaciones, GNC::GCS::Contexto3D* c)
 {
 
-	pAnotaciones->SetAnotation(TP_TopLeft, m_pAnnotator->GetTopLeftAnnotation(c));
-	pAnotaciones->SetAnotation(TP_TopRight, m_pAnnotator->GetTopRightAnnotation(c));
-	pAnotaciones->SetAnotation(TP_BottomLeft, m_pAnnotator->GetBottomLeftAnnotation(c));
-	pAnotaciones->SetAnotation(TP_BottomRight, m_pAnnotator->GetBottomRightAnnotation(c));
+	pAnotaciones->SetAnotation(Anotaciones::TP_TopLeft, m_pAnnotator->GetTopLeftAnnotation(c));
+	pAnotaciones->SetAnotation(Anotaciones::TP_TopRight, m_pAnnotator->GetTopRightAnnotation(c));
+	pAnotaciones->SetAnotation(Anotaciones::TP_BottomLeft, m_pAnnotator->GetBottomLeftAnnotation(c));
+	pAnotaciones->SetAnotation(Anotaciones::TP_BottomRight, m_pAnnotator->GetBottomRightAnnotation(c));
 
+	std::string strPos = m_pAnnotator->GetPatientPosition(c);
+	std::stringstream trimmer;
+	trimmer << strPos;
+	m_CachedPatientPosition.clear();
+	trimmer >> m_CachedPatientPosition;
 
+	pAnotaciones->m_Correcta = true;
+}
+
+//endregion
+
+void GNC::GCS::Widgets::WAnotador::RecalcularPosicion(OrientationMarks* pAnotaciones, GNC::GCS::Contexto3D* c)
+{
 	GNC::GCS::Vector3D camPos;
 	GNC::GCS::Vector3D camDir;
 	GNC::GCS::Vector3D camUp;
 
 	c->GetRenderer()->GetCamVectors(camPos.v, camDir.v, camUp.v);
-
+	
 	for (int i = 0; i < 3; ++i) {
 		if (std::abs(camUp.v[i]) < 0.1) {
 			camUp.v[i] = 0.0;
@@ -611,29 +684,28 @@ void GNC::GCS::Widgets::WAnotador::RecalcularEstaticas(Anotaciones* pAnotaciones
 			camDir.v[i] = 0.0;
 		}
 	}
-
-	GNC::GCS::Vector3D camCross = camDir.ProductoVectorial(camUp);
+	
+	GNC::GCS::Vector3D camCross = camDir.ProductoVectorial(camUp).Normalizado();
 
 	for (int i = 0; i < 3; ++i) {
 		if (std::abs(camCross.v[i]) < 0.1) {
 			camCross.v[i] = 0.0;
 		}
 	}
+	LOG_DEBUG("View", "---\nDir         : " << camDir);
+	LOG_DEBUG("View", "Up          : " << camUp);
 
 	GNC::GCS::Vector3D camOrient[3][2];
-	camOrient[0][0] = camCross.Sign(); // izq
-	camOrient[0][1] = GNC::GCS::Vector3D() - camOrient[0][0];   // der
+	camOrient[0][0] = camCross.Sign();            // izq
+	camOrient[0][1] = -camOrient[0][0];           // der
 
-	camOrient[1][0] = camUp.Stabilized().Sign();                // up
-	camOrient[1][1] = GNC::GCS::Vector3D() - camOrient[1][0];   // down
+	camOrient[1][0] = camUp.Stabilized().Sign();  // up
+	camOrient[1][1] = -camOrient[1][0];           // down
 
-	camOrient[2][0] = camDir.Stabilized().Sign();               // back
-	camOrient[2][1] = GNC::GCS::Vector3D() - camOrient[2][0];   // front
-
-	std::string strPos = m_pAnnotator->GetPatientPosition(c);
-	std::stringstream trimmer;
-	trimmer << strPos;
-	int patientPosIndex = GetOrientation(trimmer.str());
+	camOrient[2][0] = camDir.Stabilized().Sign(); // back
+	camOrient[2][1] = -camOrient[2][0];           // front
+	
+	int patientPosIndex = GetOrientation(m_CachedPatientPosition);
 
 	std::ostringstream left;
 	std::ostringstream right;
@@ -641,7 +713,7 @@ void GNC::GCS::Widgets::WAnotador::RecalcularEstaticas(Anotaciones* pAnotaciones
 	std::ostringstream bottom;
 
 	LOG_DEBUG("View", "Current orientation:");
-	LOG_DEBUG("View", "Left = " << camOrient[0][1] << ", Left = " << camOrient[0][0]);
+	LOG_DEBUG("View", "Left = " << camOrient[0][1] << ", Right = " << camOrient[0][0]);
 	LOG_DEBUG("View", "Up  = " << camOrient[1][0] << ", Down = " << camOrient[1][1]);
 
 	const int offPos = 9 * patientPosIndex;
@@ -653,30 +725,30 @@ void GNC::GCS::Widgets::WAnotador::RecalcularEstaticas(Anotaciones* pAnotaciones
 	const int offSignPos = 2;
 
 	// Left X:
-	if (camOrient[0][0][0] == 1.0) {
+	if (camOrient[0][1][0] == 1.0) {
 		left << PatientOrientation[offPos + offX + offSignPos];
 	}
-	else if (camOrient[0][0][0] == -1.0) {
+	else if (camOrient[0][1][0] == -1.0) {
 		left << PatientOrientation[offPos + offX + offSignNeg];
 	}
 	else {
 		left << PatientOrientation[offPos + offX + offSignZero];
 	}
 	// Left Y:
-	if (camOrient[0][0][1] == 1.0) {
+	if (camOrient[0][1][1] == 1.0) {
 		left << PatientOrientation[offPos + offY + offSignPos];
 	}
-	else if (camOrient[0][0][1] == -1.0) {
+	else if (camOrient[0][1][1] == -1.0) {
 		left << PatientOrientation[offPos + offY + offSignNeg];
 	}
 	else {
 		left << PatientOrientation[offPos + offY + offSignZero];
 	}
 	// Left Z:
-	if (camOrient[0][0][2] == 1.0) {
+	if (camOrient[0][1][2] == 1.0) {
 		left << PatientOrientation[offPos + offZ + offSignPos];
 	}
-	else if (camOrient[0][0][2] == -1.0) {
+	else if (camOrient[0][1][2] == -1.0) {
 		left << PatientOrientation[offPos + offZ + offSignNeg];
 	}
 	else {
@@ -684,30 +756,30 @@ void GNC::GCS::Widgets::WAnotador::RecalcularEstaticas(Anotaciones* pAnotaciones
 	}
 
 	// Right X:
-	if (camOrient[0][1][0] == 1.0) {
+	if (camOrient[0][0][0] == 1.0) {
 		right << PatientOrientation[offPos + offX + offSignPos];
 	}
-	else if (camOrient[0][1][0] == -1.0) {
+	else if (camOrient[0][0][0] == -1.0) {
 		right << PatientOrientation[offPos + offX + offSignNeg];
 	}
 	else {
 		right << PatientOrientation[offPos + offX + offSignZero];
 	}
 	// Right Y:
-	if (camOrient[0][1][1] == 1.0) {
+	if (camOrient[0][0][1] == 1.0) {
 		right << PatientOrientation[offPos + offY + offSignPos];
 	}
-	else if (camOrient[0][1][1] == -1.0) {
+	else if (camOrient[0][0][1] == -1.0) {
 		right << PatientOrientation[offPos + offY + offSignNeg];
 	}
 	else {
 		right << PatientOrientation[offPos + offY + offSignZero];
 	}
 	// Right Z:
-	if (camOrient[0][1][2] == 1.0) {
+	if (camOrient[0][0][2] == 1.0) {
 		right << PatientOrientation[offPos + offZ + offSignPos];
 	}
-	else if (camOrient[0][1][2] == -1.0) {
+	else if (camOrient[0][0][2] == -1.0) {
 		right << PatientOrientation[offPos + offZ + offSignNeg];
 	}
 	else {
@@ -775,18 +847,16 @@ void GNC::GCS::Widgets::WAnotador::RecalcularEstaticas(Anotaciones* pAnotaciones
 	else {
 		bottom << PatientOrientation[offPos + offZ + offSignZero];
 	}
-
-	pAnotaciones->SetAnotation(TP_Top, top.str());
-	pAnotaciones->SetAnotation(TP_Right, right.str());
-	pAnotaciones->SetAnotation(TP_Bottom, bottom.str());
-	pAnotaciones->SetAnotation(TP_Left, left.str());
-
-	pAnotaciones->m_Correcta = true;
+	/*
+	LOG_DEBUG("View", "==\n " << top.str());
+	LOG_DEBUG("View", left.str() << " " << right.str());
+	LOG_DEBUG("View", " " << bottom.str());
+	*/
+	pAnotaciones->SetAnotation(OrientationMarks::TP_Top, top.str());
+	pAnotaciones->SetAnotation(OrientationMarks::TP_Right, right.str());
+	pAnotaciones->SetAnotation(OrientationMarks::TP_Bottom, bottom.str());
+	pAnotaciones->SetAnotation(OrientationMarks::TP_Left, left.str());
 }
-
-//endregion
-
-
 //region "Interfaz especifica"
 
 void GNC::GCS::Widgets::WAnotador::SetAnotador(GNC::GCS::IAnotador* anotador)
@@ -849,6 +919,8 @@ void GNC::GCS::Widgets::WAnotador::OffscreenRender(GNC::GCS::Contexto3D* c)
 	//float TamFuente = TAMFUENTE;
 
 
+
+
 	const std::string        TextoAnotacion[WAnotador::TP_NumPosiciones] = { m_pAnnotator->GetTopLeftAnnotation(c), m_pAnnotator->GetTopRightAnnotation(c), m_pAnnotator->GetBottomLeftAnnotation(c), m_pAnnotator->GetBottomRightAnnotation(c) };
 	GNC::GCS::Vector         TamTexto      [WAnotador::TP_NumPosiciones];
 	GNC::GCS::Widgets::HelperTexto::TAlineamiento Alineacion[4] = { GNC::GCS::Widgets::HelperTexto::TA_Izquierda, GNC::GCS::Widgets::HelperTexto::TA_Derecha, GNC::GCS::Widgets::HelperTexto::TA_Izquierda, GNC::GCS::Widgets::HelperTexto::TA_Derecha };
