@@ -3,7 +3,7 @@
  *  $Id: wanotacionesquina.h $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -31,6 +31,7 @@ namespace GNC {
 
 			class EstadoInterno;
 			class Anotaciones;
+			class OrientationMarks;
 
 			//----------------------------------------------------------------------------------------------------
 			//region Widget anotador
@@ -69,6 +70,8 @@ namespace GNC {
 
 				virtual void RecalcularEstaticas(Anotaciones* pAnotaciones, GNC::GCS::Contexto3D* c);
 
+				virtual void RecalcularPosicion(OrientationMarks* pAnotaciones, GNC::GCS::Contexto3D* c);
+
 			//endregion
 
 				//----------------------------------------------------------------------------------------------------
@@ -114,6 +117,7 @@ namespace GNC {
 
 				EstadoInterno* m_Estado;				
 				GNC::GCS::GLHelper::TColor m_color;
+				std::string m_CachedPatientPosition;
 
 				bool m_volatileProperty[TP_NumPosiciones];
 
