@@ -3,7 +3,7 @@
  *  $Id: welipse.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -52,10 +52,12 @@ void GNC::GCS::Widgets::WElipseBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 
 		m_Stop = evento.iP;
 
-		m_BB[0].Asignar(m_Start.x, m_Start.y);
-		m_BB[1].Asignar(m_Stop.x, m_Start.y);
-		m_BB[2].Asignar(m_Stop.x, m_Stop.y);
-		m_BB[3].Asignar(m_Start.x, m_Stop.y);
+		GNC::GCS::Vector a = m_Start.ProyeccionOrtogonalSobreRecta(m_Stop,  m_Stop - evento.c->ScreenDirectionCosines[0]);		
+		GNC::GCS::Vector b = m_Start.ProyeccionOrtogonalSobreRecta(m_Stop,  m_Stop - evento.c->ScreenDirectionCosines[1]);
+		m_BB[0] = m_Start;
+		m_BB[1] = a;
+		m_BB[2] = m_Stop;
+		m_BB[3] = b;
 
 
 		TVector diff = m_Stop - m_Start;
@@ -65,12 +67,19 @@ void GNC::GCS::Widgets::WElipseBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 			bBox[1] = m_BB[2];
 			GNC::GCS::Vector::OrdenarBoundingBox(bBox);
 
+			TVector centro = m_BB[0].PuntoMedio(m_BB[2]);
+
+			TVector m_RadioMayor = m_BB[0] - m_BB[1];
+			TVector m_RadioMenor = m_BB[0] - m_BB[3];
+
+			/*
 			TVector centro = bBox[0].PuntoMedio(bBox[1]);
 
 			TVector radio1(bBox[1].x - centro.x, 0.0f);
 			TVector radio2(0.0f, bBox[1].y - centro.y);
+			*/
 
-			WElipse* w = new WElipse(centro, radio1, radio2, m_pManager, evento.c->GetRenderer()->GetVID(), "Elipse", m_GID);
+			WElipse* w = new WElipse(centro, m_RadioMayor/2, m_RadioMenor/2, m_pManager, evento.c->GetRenderer()->GetVID(), "Elipse", m_GID);
 			m_pManager->InsertarWidget(w);
 			m_pManager->LanzarEventoCreacion(w);
 			ConsumirEvento();
@@ -88,10 +97,12 @@ void GNC::GCS::Widgets::WElipseBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 		m_Start = evento.iP;
 		m_Stop = m_Start;
 
-		m_BB[0].Asignar(m_Start.x, m_Start.y);
-		m_BB[1].Asignar(m_Stop.x, m_Start.y);
-		m_BB[2].Asignar(m_Stop.x, m_Stop.y);
-		m_BB[3].Asignar(m_Start.x, m_Stop.y);
+		GNC::GCS::Vector a = m_Start.ProyeccionOrtogonalSobreRecta(m_Stop,  m_Stop - evento.c->ScreenDirectionCosines[0]);		
+		GNC::GCS::Vector b = m_Start.ProyeccionOrtogonalSobreRecta(m_Stop,  m_Stop - evento.c->ScreenDirectionCosines[1]);
+		m_BB[0] = m_Start;
+		m_BB[1] = a;
+		m_BB[2] = m_Stop;
+		m_BB[3] = b;
 
 		m_pManager->Modificado();
 		m_Estado = WBS_Creando;
@@ -104,10 +115,12 @@ void GNC::GCS::Widgets::WElipseBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 
 		m_Stop = evento.iP;
 
-		m_BB[0].Asignar(m_Start.x, m_Start.y);
-		m_BB[1].Asignar(m_Stop.x, m_Start.y);
-		m_BB[2].Asignar(m_Stop.x, m_Stop.y);
-		m_BB[3].Asignar(m_Start.x, m_Stop.y);
+		GNC::GCS::Vector a = m_Start.ProyeccionOrtogonalSobreRecta(m_Stop,  m_Stop - evento.c->ScreenDirectionCosines[0]);		
+		GNC::GCS::Vector b = m_Start.ProyeccionOrtogonalSobreRecta(m_Stop,  m_Stop - evento.c->ScreenDirectionCosines[1]);
+		m_BB[0] = m_Start;
+		m_BB[1] = a;
+		m_BB[2] = m_Stop;
+		m_BB[3] = b;
 
 		m_pManager->Modificado();
 		evento.Skip(false);
@@ -128,11 +141,16 @@ void GNC::GCS::Widgets::WElipseBuilder::Render(GNC::GCS::Contexto3D* /*c*/)
 {
 
 	if (m_Estado == WBS_Creando) {
-
-
 		TVector centro = m_BB[0].PuntoMedio(m_BB[2]);
-		TVector radios = ((m_BB[2] - m_BB[0]) / 2.0f).ValorAbsoluto();
 
+		TVector m_RadioMayor = m_BB[0] - m_BB[1];
+		TVector m_RadioMenor = m_BB[0] - m_BB[3];
+
+		double m_NormaRadioMayor = m_RadioMayor.Norma2()/2;
+		double m_NormaRadioMenor = m_RadioMenor.Norma2()/2;
+
+		double m_Angulo = m_RadioMayor.AnguloSobreAbscisa();
+		
 		float step = M_2PI / 100;
 
 		glLineWidth(2.0f);
@@ -141,11 +159,12 @@ void GNC::GCS::Widgets::WElipseBuilder::Render(GNC::GCS::Contexto3D* /*c*/)
 
 			for ( float angulo = 0; angulo < M_2PI; angulo += step)
 			{
-				glVertex3f(centro.x + (radios.x * cos (angulo)) , centro.y + (radios.y * sin (angulo)), 0.0f);
+				GNC::GCS::Vector v (m_NormaRadioMayor * cos(angulo), m_NormaRadioMenor * sin(angulo));
+				v = centro + v.RotacionSobreZ(m_Angulo);
+				glVertex3f(v.x , v.y, 0.0f);
 			}
 
 		glEnd();
-
 	}
 	else {
 
@@ -161,7 +180,7 @@ GNC::GCS::Widgets::TipoCursor GNC::GCS::Widgets::WElipseBuilder::GetCursor()
 
 //region "Constructor y destructor"
 
-GNC::GCS::Widgets::WElipse::WElipse(TVector centro, TVector radio1, TVector radio2, IWidgetsManager* pManager, long vid, const char* nombre, long gid) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre, gid), GNC::GCS::Widgets::IWidgetSerializable()
+GNC::GCS::Widgets::WElipse::WElipse(TVector centro, TVector radio1, TVector radio2, IWidgetsManager* pManager, long vid, const char* nombre, long gid) : GNC::GCS::Widgets::IWidget(pManager, vid, nombre, gid,TID_USER_ANNOTATION_WIDGET), GNC::GCS::Widgets::IWidgetSerializable()
 {
 	m_Centro = centro;
 	m_RadioMayor = radio1;
