@@ -3,7 +3,7 @@
  *  $Id: visualizatorcontroller.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -203,13 +203,14 @@ bool GNKVisualizator::ControladorAtencionPrimaria::SupportsImportationUID(const
 }
 
 //helper opening...
-GNC::GCS::IVista* OpenMedicalImageViewer(const std::set<long>& seriesPk, wxWindow* pParent, GNC::GCS::IEntorno* pEntorno, GNC::GCS::IModuleController* pModule, const GNC::GCS::Ptr<GNC::GCS::Layout>& hangingLayout)
+GNC::GCS::IVista* OpenMedicalImageViewer(const std::set<long>& seriesPk, wxWindow* pParent, GNC::GCS::IEntorno* pEntorno, GNC::GCS::IModuleController* pModule, const GNC::GCS::Ptr<GNC::GCS::Layout>& hangingLayout, const GNC::GCS::Ptr<GNC::GCS::HangingProtocol>& hangingProtocol)
 {
 	wxWindowDisabler disabler;
 	GNC::GCS::Ptr<GNKVisualizator::VisualizatorStudy> estudio = new GNKVisualizator::VisualizatorStudy();
 	estudio->OpenedSeries.insert(estudio->OpenedSeries.begin(), seriesPk.begin(), seriesPk.end());
 	estudio->Module = pModule;
 	estudio->hangingLayout = hangingLayout;
+	estudio->hangingProtocol = hangingProtocol;
 	estudio->ParentWindow = pParent;
 	estudio->InitializeContext(*seriesPk.begin());
 	GNC::GCS::IVista* pVista = new GNKVisualizator::Vista2D(estudio);
@@ -298,10 +299,10 @@ GNC::GCS::IVista* GNKVisualizator::ControladorAtencionPrimaria::OpenView(int mod
 				if (hangingProtocol.IsValid() && !hangingProtocol->getLayouts().empty())  {
 					for (GNC::GCS::HangingProtocol::TListOfLayouts::const_iterator it = hangingProtocol->getLayouts().begin(); it != hangingProtocol->getLayouts().end(); ++it)
 					{
-						pVista = OpenMedicalImageViewer(pkSeries, pVentanaPadre, m_pEntorno, this, (*it));
+						pVista = OpenMedicalImageViewer(pkSeries, pVentanaPadre, m_pEntorno, this, (*it), hangingProtocol);
 					}
 				} else {
-					pVista = OpenMedicalImageViewer(pkSeries, pVentanaPadre, m_pEntorno, this, NULL);
+					pVista = OpenMedicalImageViewer(pkSeries, pVentanaPadre, m_pEntorno, this, NULL, NULL);
 				}
 				
 			}
