@@ -3,7 +3,7 @@
  *  $Id: gvistacompleja.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -25,8 +25,11 @@
 #include <visualizator/estudios/overlay.h>
 #include <resources/ginkgoresourcesmanager.h>
 #include <resources/visualizatorresourcesmanager.h>
+#include <api/dicom/idicommanager.h>
+#include <api/dicom/dcmdictionary.h>
 
 #include <api/autoptr.h>
+#include <export/contracts/ipixelsbluringcontract.h>
 
 #include "../eventos/visualizatorevents.h"
 #include <api/controllers/icontroladorlog.h>
@@ -47,7 +50,6 @@
 #include <vtk/widgets/widgetsactor.h>
 #include <vtkCamera.h>
 #include <vtkPointData.h>
-#include <vtkImageBlend.h>
 #include <vtkImageMathematics.h>
 #include <api/westilo.h>
 
@@ -63,7 +65,6 @@
 
 #include <cairo/cairo.h>
 #include <widgets/openglhelper.h>
-//#include <widgets/wprogreso.h>
 #include <widgets/wanotacionesquina.h>
 
 
@@ -319,7 +320,7 @@ public:
 			GView->GoToSlice(slicenum, false);
 		}
 		else {
-			bool ok = true;
+			//bool ok = true;
 			for(GVistaCompleja::TListaGVistasSimples::iterator it = GView->m_VistasSimples.begin(); it != GView-> m_VistasSimples.end(); ++it) {
 				GVistaSimple* vs = *it;
 				vs->GoToTSlice(slicenum, false);
@@ -375,12 +376,68 @@ public:
 		return true;
 	}
 
+	virtual void DoAutoCalculateWindowLevel()
+	{
+		for(GVistaCompleja::TListaGVistasSimples::iterator it = GView->m_VistasSimples.begin(); it != GView->m_VistasSimples.end(); ++it) {
+			(*it)->ViewImage2D->SetAutoDefaultWindowLevel();
+			(*it)->ViewImage2D->ResetToDefaultWindowLevel();
+			SetUserDefinedWindowLevel((*it)->ViewImage2D->GetWindow(), (*it)->ViewImage2D->GetLevel());
+		}
+	}
+
+	virtual void DoResetWindowLevel() 
+	{
+		if (HasDefaultWindowLevel()) {
+			GNC::GCS::IWindowLevelContract::WindowLevel defWl = GetAndSetDefaultWindowLevel();
+			for(GVistaCompleja::TListaGVistasSimples::iterator it = GView->m_VistasSimples.begin(); it != GView->m_VistasSimples.end(); ++it) {
+				(*it)->ViewImage2D->SetDefaultWindowLevel(defWl.m_window, defWl.m_level);			
+				(*it)->ViewImage2D->ResetToDefaultWindowLevel();
+			}
+		} else {
+			DoAutoCalculateWindowLevel();
+		}
+	}
+
+	virtual void DoSetWindowLevel(double window, double level)
+	{
+		for(GVistaCompleja::TListaGVistasSimples::iterator it = GView->m_VistasSimples.begin(); it != GView->m_VistasSimples.end(); ++it) {
+			(*it)->ViewImage2D->SetWindow(window);
+			(*it)->ViewImage2D->SetLevel(level);						
+		}
+	}
+
 protected:
 	GVistaCompleja* GView;
 	ListaWindowLevels m_listaWindowLevels;
 	std::string m_labelCurrent;
 };
 
+class GVistaComplejaPixelsBluringDelegate: public GNC::GCS::IPixelsBluringContract
+{
+	public:
+		GVistaComplejaPixelsBluringDelegate(GVistaCompleja* gView):GView(gView)
+		{
+		}
+
+		~GVistaComplejaPixelsBluringDelegate()
+		{
+		}
+		vtkGinkgoImageViewer* GetViewerActivo()
+		{
+			return GView->Delegate->GetViewerActivo();
+		}
+		virtual GNC::GCS::IWidgetsManager* GetManager()
+		{ 
+			return GView->m_pManager; 
+		}
+		virtual void GetAllViewers(std::list<vtkGinkgoImageViewer*>& viewerList)
+		{
+			return GView->Delegate->GetAllViewers(viewerList);
+		} 
+
+		GVistaCompleja* GView;
+};
+
 //contracts dellegate
 
 /////////////////////////////////////DRAG&DROP/////////////////////////////////////////
@@ -399,8 +456,7 @@ namespace GNKVisualizator {
 			{
 			}
 
-			virtual wxDragResult OnDragOver(wxCoord x, wxCoord y,
-												wxDragResult def)
+			virtual wxDragResult OnDragOver(wxCoord x, wxCoord y, wxDragResult /*def*/)
 			{ 
 				wxPoint coords(x, y);
 				coords = GView->ClientToScreen(coords);
@@ -413,7 +469,7 @@ namespace GNKVisualizator {
 			  return wxDragNone; 
 			}
 
-			virtual wxDragResult OnData(wxCoord x, wxCoord y, wxDragResult def)
+			virtual wxDragResult OnData(wxCoord x, wxCoord y, wxDragResult /*def*/)
 			{
 				if ( !GetData() )
 					  return wxDragNone;
@@ -446,7 +502,8 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 	WindowLayoutDelegate(new GVistaComplejaWindowLayoutDelegate(this)),
 	m_pManager (GNC::GCS::IEntorno::Instance()->NewWidgetsManager(IVista)),
 	ExportDelegate(new GNKVisualizator::SimpleViewExportContractDelegate(this)),
-	m_pPanelPreview(new GNKVisualizator::GUI::PreviewPanelVisualizator(pIVista, this))
+	m_pPanelPreview(new GNKVisualizator::GUI::PreviewPanelVisualizator(pIVista, this)),
+	PixelsBluringDelegate(new GVistaComplejaPixelsBluringDelegate(this))
 {
 	IVista->GetVisualizatorStudy()->Window = this;
 	m_hasBeenRendered = false;
@@ -475,7 +532,7 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 	pToolBar->AddTool(HCore_CornerAnnotations, (GNC::GCS::ISliderContract*) Delegate);
 	pToolBar->AddTool(HCore_DetachWindow, (GNC::GCS::IViewContract*) IVista);
 	pToolBar->AddTool(HCore_MetricGrid, (GNC::GCS::ISliderContract*) Delegate);
-	pToolBar->AddTool(HCore_PixelsBluring, (GNC::GCS::ISliderContract*) Delegate);
+	pToolBar->AddTool(HCore_PixelsBluring, PixelsBluringDelegate);
 	pToolBar->AddTool(HCore_Reset, (GNC::GCS::ISliderContract*) Delegate);
 	pToolBar->AddTool(HCore_WindowLayout, WindowLayoutDelegate);
 	pToolBar->AddTool(HCore_RotateAndFlip, (GNC::GCS::ISliderContract*) Delegate);
@@ -493,6 +550,7 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 	pToolBar->AddTool(HCore_PACSUpload, (GNC::GCS::IViewContract*) IVista);
 	pToolBar->AddTool(HCore_DicomizeFromView, (GNC::GCS::IViewContract*) IVista);
 	pToolBar->AddTool(HCore_AddFileToHistory, (GNC::GCS::IViewContract*) IVista);
+	pToolBar->AddTool(HCore_QueryRetrieve, (GNC::GCS::IViewContract*) IVista);
 
 	m_pSizerTools->Add(pToolBar->CreateNewToolBar(this, GNC::GCS::ITool::TFamiliaVisualizacion), 0, wxEXPAND);
 	m_pSizerTools->Add(pToolBar->CreateNewToolBar(this, GNC::GCS::ITool::TFamiliaMedicion), 0, wxEXPAND);
@@ -678,8 +736,9 @@ void GVistaCompleja::IniciarPipeline(const GNC::GCS::Ptr<GNC::GCS::Layout>& layo
 
 	//contratos que son 1:1 con gvistacompleja
 	//esto es correcto porque en la creacion se mete siempre una vista simple
-
-	Delegate->Setup(*IVista->GetEstudio()->GetTagsActiveImage());
+	GNC::GCS::Ptr<GIL::DICOM::DicomDataset> ds = IVista->GetEstudio()->GetTagsActiveImage();
+	Delegate->Setup(*ds);
+	PixelsBluringDelegate->Setup(ds->getTag(GKDCM_Modality));
 
 
 	///////////recorrer las vistas simples y pasarles las imagenes	
@@ -1123,12 +1182,12 @@ std::string GVistaCompleja::GetPatientPosition(GNC::GCS::Contexto3D* c) {
 	return "";
 }
 
-std::string GVistaCompleja::GetAnotacionPosicion(GNC::GCS::Vector* pPosicion)
+std::string GVistaCompleja::GetAnotacionPosicion(const GNC::GCS::Vector3D& wP, GNC::GCS::Contexto3D* c)
 {
 	GNC::GCS::IWidgetsRenderer* r = m_pManager->GetRendererActivo();
 	for (TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); ++it) {
 		if ( (*it)->ViewInteractor2D == r) {
-			return (*it)->GetAnotacionPosicion(pPosicion);
+			return (*it)->GetAnotacionPosicion(wP, c);
 		}
 	}
 	return "";
@@ -1164,7 +1223,7 @@ public:
 
 	}
 
-	void OnAceptarClick(wxCommandEvent &event){
+	void OnAceptarClick(wxCommandEvent&){
 		EndModal(wxID_OK);
 	}
 
@@ -1189,7 +1248,7 @@ protected:
 
 //---------- end DIALOGO SINCRONIZACION...-------------
 
-void GVistaCompleja::OnSincronizarClick(wxCommandEvent &event)
+void GVistaCompleja::OnSincronizarClick(wxCommandEvent&)
 {
 	bool enabled = m_pBarraDerecha->GetToolToggled(ID_BOTON_SINCRONIZAR);
 	Sincronizar(enabled);
@@ -1489,31 +1548,17 @@ void GVistaCompleja::ProcesarEvento(GNC::GCS::Events::IEvent *evt)
 					break;
 					case GNC::GCS::Events::EventoModificacionImagen::VisualizacionImagenModificada:
 						//para que pille bien el window/level
-						for(TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); ++it) {
-							if (pEvt->AutoCalculeWindowLevel()) {
-								(*it)->ViewImage2D->SetAutoDefaultWindowLevel();
-								(*it)->ViewImage2D->ResetToDefaultWindowLevel();
-								Delegate->SetUserDefinedWindowLevel((*it)->ViewImage2D->GetWindow(), (*it)->ViewImage2D->GetLevel());
+						if (pEvt->AutoCalculeWindowLevel()) {
+							Delegate->DoAutoCalculateWindowLevel();
+						} else {
+							if(pEvt->ResetWindowLevel()) {
+								Delegate->DoResetWindowLevel();
 							} else {
-								if(pEvt->ResetWindowLevel()) {
-									if (Delegate->HasDefaultWindowLevel()) {
-										GNC::GCS::IWindowLevelContract::WindowLevel wl = Delegate->GetAndSetDefaultWindowLevel();
-										(*it)->ViewImage2D->SetDefaultWindowLevel(wl.m_window, wl.m_level);			
-									} else {
-										(*it)->ViewImage2D->SetAutoDefaultWindowLevel();
-									}
-
-									(*it)->ViewImage2D->ResetToDefaultWindowLevel();
-								} else {
-									(*it)->ViewImage2D->SetWindow(pEvt->GetWindow());
-									(*it)->ViewImage2D->SetLevel(pEvt->GetLevel());
-									//(*it)->ViewImage2D->UpdateImage();
-									for(TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); ++it) {
-																							  //(*it)->ViewInteractor2D->Refresh(false);
-																							  //(*it)->ViewInteractor2D->Render();
-									}
-								}
+								Delegate->DoSetWindowLevel(pEvt->GetWindow(), pEvt->GetLevel());
 							}
+						}
+
+						for(TListaGVistasSimples::iterator it = m_VistasSimples.begin(); it != m_VistasSimples.end(); ++it) {
 							if(pEvt->ResetCurrentPoint())
 							{
 								/*
