@@ -3,7 +3,7 @@
  *  $Id: gvistasimple.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -53,9 +53,7 @@ public:
 		return new GVtkObserver;
 	}
 
-	void Execute(vtkObject *   caller,
-				 unsigned long event,
-				 void *        callData)
+	void Execute(vtkObject * caller, unsigned long event, void * /*callData*/)
 	{
 		if (IVista == NULL) {
 			return;
@@ -258,7 +256,7 @@ GNC::GCS::Ptr<GNC::GCS::IReferredStudyContext>& GVistaSimple::GetEstudio()
 	return EstudioReferido;
 }
 
-void GVistaSimple::OnFocus(wxChildFocusEvent &event )
+void GVistaSimple::OnFocus(wxChildFocusEvent& /*event*/)
 {
 	if (IVista != NULL) {
 		IVista->OnFocus();
@@ -320,7 +318,7 @@ void GVistaSimple::GoToTSlice(int pos, bool relativa)
 	}
 }
 
-void GVistaSimple::GoToSlice(int pos, bool relativa, bool propagar)
+void GVistaSimple::GoToSlice(int pos, bool relativa, bool /*propagar*/)
 {
 	int posicion;
 	if(relativa){
@@ -503,7 +501,7 @@ std::string GVistaSimple::GetBottomLeftAnnotation(GNC::GCS::Contexto3D* c) {
 	return os.str();
 }
 
-std::string GVistaSimple::GetBottomRightAnnotation(GNC::GCS::Contexto3D* c) {
+std::string GVistaSimple::GetBottomRightAnnotation(GNC::GCS::Contexto3D* /*c*/) {
 	if (!this->ViewImage2D->IsInstalledAndInitialized() || IVista == NULL)
 		return "";
 
@@ -550,12 +548,12 @@ std::string GVistaSimple::GetBottomRightAnnotation(GNC::GCS::Contexto3D* c) {
 	return os.str();
 }
 
-std::string GVistaSimple::GetPatientPosition(GNC::GCS::Contexto3D* c)
+std::string GVistaSimple::GetPatientPosition(GNC::GCS::Contexto3D* /*c*/)
 {
 	return IVista->GetDICOMTagOriginal("0018|5100");
 }
 
-std::string GVistaSimple::GetAnotacionPosicion(GNC::GCS::Vector* pPosicion)
+std::string GVistaSimple::GetAnotacionPosicion(const GNC::GCS::Vector3D& wP, GNC::GCS::Contexto3D* c)
 {
 	if (!this->ViewImage2D->IsInstalledAndInitialized() || IVista == NULL)
 		return "";
@@ -565,17 +563,15 @@ std::string GVistaSimple::GetAnotacionPosicion(GNC::GCS::Vector* pPosicion)
 	os.precision(2);
 	os.fill('0');
 
-	double ip[3] = {pPosicion->x, pPosicion->y, 0.0};
+	double ip[3] = {0,0,0};
+	c->pRenderer->m_pImageViewer->Proyect2D(wP.v, ip);
 	int pp[3] = {0, 0, 0};
-	double wp[3] = {0.0,0.0,0.0};
 	int dims[3];
 
 	ViewImage2D->GetDimensions(dims);
 
-	ViewImage2D->CoordenadasImagenACoordenadasMundo(ip,wp);
 
-
-	os << _Std("Position:") << " W:(" << wp[0] << ", " << wp[1] << "," << wp[2] << "); I:(" << pPosicion->x << ", " << pPosicion->y << ")";
+	os << _Std("Position:") << " W:(" << wP.x << ", " << wP.y << "," << wP.z << "); I:(" << ip[0] << ", " << ip[1] << ")";
 
 	//corregir de convención DICOM a convención vtk
 
@@ -654,7 +650,7 @@ inline bool my_isnan(float x)
 }
 
 //region "Interfaz de impresion de overlays de widgets"
-void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Contexto3D* c, GNC::GCS::Vector& boundingBox)
+void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Contexto3D* c, GNC::GCS::Vector& /*boundingBox*/)
 {
 	if (!w->EsMarcador()) {
 		return;
@@ -948,7 +944,7 @@ void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidget* w, GNC::GCS::Cont
 	}
 }
 
-void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidgetBuilder* wb, GNC::GCS::Contexto3D* c, GNC::GCS::Vector& boundingBox)
+void GVistaSimple::ImprimirOverlay(GNC::GCS::Widgets::IWidgetBuilder* /*wb*/, GNC::GCS::Contexto3D* /*c*/, GNC::GCS::Vector& /*boundingBox*/)
 {
 	//std::cout << "GVistaPASI::ImprimirOverlay() " << wb << std::endl;
 }
