@@ -3,7 +3,7 @@
 *  $Id: gwaveformview.cpp $
 *  Ginkgo CADx Project
 *
-*  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
@@ -39,7 +39,6 @@
 #include <api/toolsystem/itoolcontroller.h>
 #include <api/toolsystem/itool.h>
 
-
 #define ANNOTATOR_TEXT_COLOR 0.1f, 0.1f, 0.1f, 1.0f
 
 #define ID_BUTTON_METADATA 0
@@ -194,7 +193,6 @@ namespace GNKVisualizator
 			Thaw();
 		}
 
-
 		GWaveformView::~GWaveformView()
 		{
 			this->Disconnect(wxEVT_CHILD_FOCUS, wxChildFocusEventHandler(GWaveformView::OnFocus),NULL,this);
@@ -235,7 +233,6 @@ namespace GNKVisualizator
 			if(ViewImage2D != NULL) {
 				// FIXME: Comprobar si el pipeline esta conectado.
 				ViewImage2D->SetupPipeline();
-
 				
 				WECG = new GNKVisualizator::Widgets::WECG(GetManager(), 0);
 					GetManager()->InsertarWidget(WECG, false);
@@ -263,7 +260,6 @@ namespace GNKVisualizator
 			}
 		}
 
-		
 		void GWaveformView::StopPipeline()
 		{
 			m_pManager->OcultarTodosLosWidgets(true, 666);
@@ -303,7 +299,7 @@ namespace GNKVisualizator
 			}
 		}
 	
-		void GWaveformView::OnComboGroup(wxCommandEvent &event)
+		void GWaveformView::OnComboGroup(wxCommandEvent &)
 		{
 			View->GetECGStudy()->SetIndexOfActualMultiplexGroup(m_pComboGroups->GetSelection());
 			WECG->Reload(View->GetECGStudy()->GetListOfChannels());
@@ -330,13 +326,12 @@ namespace GNKVisualizator
 			}
 		}
 
-		void GWaveformView::OnShowHideCornerAnnotations(wxCommandEvent &event)
+		void GWaveformView::OnShowHideCornerAnnotations(wxCommandEvent &)
 		{
 			m_pManager->MostrarOcultarAnotador();			
 			GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(new GNC::GCS::Events::EventoRender(View));
 		}
 
-
 		//IAnotador
 		std::string GWaveformView::GetDICOMTag(std::string tagId)
 		{
@@ -346,7 +341,7 @@ namespace GNKVisualizator
 			return str;
 		}
 
-		std::string GWaveformView::GetTopLeftAnnotation(GNC::GCS::Contexto3D* c)
+		std::string GWaveformView::GetTopLeftAnnotation(GNC::GCS::Contexto3D*)
 		{
 			if (!this->ViewImage2D->IsInstalledAndInitialized() || View == NULL)
 				return "";
@@ -365,7 +360,7 @@ namespace GNKVisualizator
 			return os.str();
 		}
 
-		std::string GWaveformView::GetTopRightAnnotation(GNC::GCS::Contexto3D* c)
+		std::string GWaveformView::GetTopRightAnnotation(GNC::GCS::Contexto3D*)
 		{
 			if (!this->ViewImage2D->IsInstalledAndInitialized() || View == NULL)
 				return "";
@@ -417,7 +412,7 @@ namespace GNKVisualizator
 			return os.str();
 		}
 
-		std::string GWaveformView::GetBottomLeftAnnotation(GNC::GCS::Contexto3D* c)
+		std::string GWaveformView::GetBottomLeftAnnotation(GNC::GCS::Contexto3D*)
 		{
 			
 			if (!this->ViewImage2D->IsInstalledAndInitialized() || View == NULL)
@@ -467,7 +462,7 @@ namespace GNKVisualizator
 			return os.str();
 		}
 
-		std::string GWaveformView::GetBottomRightAnnotation(GNC::GCS::Contexto3D* c)
+		std::string GWaveformView::GetBottomRightAnnotation(GNC::GCS::Contexto3D*)
 		{
 			if (!this->ViewImage2D->IsInstalledAndInitialized() || View == NULL)
 				return "";
@@ -476,19 +471,19 @@ namespace GNKVisualizator
 			return os.str();
 		}
 
-		std::string GWaveformView::GetPatientPosition(GNC::GCS::Contexto3D* c)
+		std::string GWaveformView::GetPatientPosition(GNC::GCS::Contexto3D*)
 		{
 			return "";
 		}
 
-		std::string GWaveformView::GetAnotacionPosicion(GNC::GCS::Vector* pPosicionRaton)
+		std::string GWaveformView::GetAnotacionPosicion(const GNC::GCS::Vector3D& /*wP*/, GNC::GCS::Contexto3D*)
 		{
 			return "";
 		}
 
 		//end ianotador
 
-		void GWaveformView::OnFocus(wxChildFocusEvent &event)
+		void GWaveformView::OnFocus(wxChildFocusEvent &)
 		{
 			if (View != NULL) {
 				View->OnFocus();
